Module debugger

Module debugger 

Debugger domain exposes JavaScript debugging capabilities. It allows setting and removing breakpoints, stepping through execution, exploring stack traces, etc.

Structs

BreakLocation
BreakLocationBuilder
CallFrame
JavaScript call frame. Array of call frames form the call stack.
CallFrameBuilder
ContinueToLocationParams
Continues execution until specific location is reached.
ContinueToLocationParamsBuilder
DebugSymbols
Debug symbols available for a wasm script.
DebugSymbolsBuilder
DisableParams
DisassembleWasmModuleParams
DisassembleWasmModuleParamsBuilder
DisassembleWasmModuleReturns
DisassembleWasmModuleReturnsBuilder
EnableParams
Enables debugger for the given page. Clients should not assume that the debugging has been enabled until the result for this command is received.
EnableParamsBuilder
EnableReturns
Enables debugger for the given page. Clients should not assume that the debugging has been enabled until the result for this command is received.
EnableReturnsBuilder
EvaluateOnCallFrameParams
Evaluates expression on a given call frame.
EvaluateOnCallFrameParamsBuilder
EvaluateOnCallFrameReturns
Evaluates expression on a given call frame.
EvaluateOnCallFrameReturnsBuilder
GetPossibleBreakpointsParams
Returns possible locations for breakpoint. scriptId in start and end range locations should be the same.
GetPossibleBreakpointsParamsBuilder
GetPossibleBreakpointsReturns
Returns possible locations for breakpoint. scriptId in start and end range locations should be the same.
GetPossibleBreakpointsReturnsBuilder
GetScriptSourceParams
Returns source for the script with given id.
GetScriptSourceParamsBuilder
GetScriptSourceReturns
Returns source for the script with given id.
GetScriptSourceReturnsBuilder
GetStackTraceParams
Returns stack trace with given ‘stackTraceId’.
GetStackTraceParamsBuilder
GetStackTraceReturns
Returns stack trace with given ‘stackTraceId’.
GetStackTraceReturnsBuilder
GetWasmBytecodeParams
This command is deprecated. Use getScriptSource instead.
GetWasmBytecodeParamsBuilder
GetWasmBytecodeReturns
This command is deprecated. Use getScriptSource instead.
GetWasmBytecodeReturnsBuilder
Location
Location in the source code.
LocationBuilder
LocationRange
Location range within one script.
LocationRangeBuilder
NextWasmDisassemblyChunkParams
Disassemble the next chunk of lines for the module corresponding to the stream. If disassembly is complete, this API will invalidate the streamId and return an empty chunk. Any subsequent calls for the now invalid stream will return errors.
NextWasmDisassemblyChunkParamsBuilder
NextWasmDisassemblyChunkReturns
Disassemble the next chunk of lines for the module corresponding to the stream. If disassembly is complete, this API will invalidate the streamId and return an empty chunk. Any subsequent calls for the now invalid stream will return errors.
NextWasmDisassemblyChunkReturnsBuilder
PauseOnAsyncCallParams
PauseOnAsyncCallParamsBuilder
PauseParams
RemoveBreakpointParams
Removes JavaScript breakpoint.
RemoveBreakpointParamsBuilder
ResolvedBreakpoint
ResolvedBreakpointBuilder
RestartFrameParams
Restarts particular call frame from the beginning. The old, deprecated behavior of ‘restartFrame’ is to stay paused and allow further CDP commands after a restart was scheduled. This can cause problems with restarting, so we now continue execution immediatly after it has been scheduled until we reach the beginning of the restarted frame.
RestartFrameParamsBuilder
RestartFrameReturns
Restarts particular call frame from the beginning. The old, deprecated behavior of ‘restartFrame’ is to stay paused and allow further CDP commands after a restart was scheduled. This can cause problems with restarting, so we now continue execution immediatly after it has been scheduled until we reach the beginning of the restarted frame.
RestartFrameReturnsBuilder
ResumeParams
Resumes JavaScript execution.
ResumeParamsBuilder
Scope
Scope description.
ScopeBuilder
ScriptPosition
Location in the source code.
ScriptPositionBuilder
SearchInContentParams
Searches for given string in script content.
SearchInContentParamsBuilder
SearchInContentReturns
Searches for given string in script content.
SearchInContentReturnsBuilder
SearchMatch
Search match for resource.
SearchMatchBuilder
SetAsyncCallStackDepthParams
Enables or disables async call stacks tracking.
SetAsyncCallStackDepthParamsBuilder
SetBlackboxExecutionContextsParams
Replace previous blackbox execution contexts with passed ones. Forces backend to skip stepping/pausing in scripts in these execution contexts. VM will try to leave blackboxed script by performing ‘step in’ several times, finally resorting to ‘step out’ if unsuccessful.
SetBlackboxExecutionContextsParamsBuilder
SetBlackboxPatternsParams
Replace previous blackbox patterns with passed ones. Forces backend to skip stepping/pausing in scripts with url matching one of the patterns. VM will try to leave blackboxed script by performing ‘step in’ several times, finally resorting to ‘step out’ if unsuccessful.
SetBlackboxPatternsParamsBuilder
SetBlackboxedRangesParams
Makes backend skip steps in the script in blackboxed ranges. VM will try leave blacklisted scripts by performing ‘step in’ several times, finally resorting to ‘step out’ if unsuccessful. Positions array contains positions where blackbox state is changed. First interval isn’t blackboxed. Array should be sorted.
SetBlackboxedRangesParamsBuilder
SetBreakpointByUrlParams
Sets JavaScript breakpoint at given location specified either by URL or URL regex. Once this command is issued, all existing parsed scripts will have breakpoints resolved and returned in ‘locations’ property. Further matching script parsing will result in subsequent ‘breakpointResolved’ events issued. This logical breakpoint will survive page reloads.
SetBreakpointByUrlParamsBuilder
SetBreakpointByUrlReturns
Sets JavaScript breakpoint at given location specified either by URL or URL regex. Once this command is issued, all existing parsed scripts will have breakpoints resolved and returned in ‘locations’ property. Further matching script parsing will result in subsequent ‘breakpointResolved’ events issued. This logical breakpoint will survive page reloads.
SetBreakpointByUrlReturnsBuilder
SetBreakpointOnFunctionCallParams
Sets JavaScript breakpoint before each call to the given function. If another function was created from the same source as a given one, calling it will also trigger the breakpoint.
SetBreakpointOnFunctionCallParamsBuilder
SetBreakpointOnFunctionCallReturns
Sets JavaScript breakpoint before each call to the given function. If another function was created from the same source as a given one, calling it will also trigger the breakpoint.
SetBreakpointOnFunctionCallReturnsBuilder
SetBreakpointParams
Sets JavaScript breakpoint at a given location.
SetBreakpointParamsBuilder
SetBreakpointReturns
Sets JavaScript breakpoint at a given location.
SetBreakpointReturnsBuilder
SetBreakpointsActiveParams
Activates / deactivates all breakpoints on the page.
SetBreakpointsActiveParamsBuilder
SetInstrumentationBreakpointParams
Sets instrumentation breakpoint.
SetInstrumentationBreakpointParamsBuilder
SetInstrumentationBreakpointReturns
Sets instrumentation breakpoint.
SetInstrumentationBreakpointReturnsBuilder
SetPauseOnExceptionsParams
Defines pause on exceptions state. Can be set to stop on all exceptions, uncaught exceptions, or caught exceptions, no exceptions. Initial pause on exceptions state is ‘none’.
SetPauseOnExceptionsParamsBuilder
SetReturnValueParams
Changes return value in top frame. Available only at return break position.
SetReturnValueParamsBuilder
SetScriptSourceParams
Edits JavaScript source live.
SetScriptSourceParamsBuilder
SetScriptSourceReturns
Edits JavaScript source live.
SetScriptSourceReturnsBuilder
SetSkipAllPausesParams
Makes page not interrupt on any pauses (breakpoint, exception, dom exception etc).
SetSkipAllPausesParamsBuilder
SetVariableValueParams
Changes value of variable in a callframe. Object-based scopes are not supported and must be mutated manually.
SetVariableValueParamsBuilder
StepIntoParams
Steps into the function call.
StepIntoParamsBuilder
StepOutParams
StepOverParams
Steps over the statement.
StepOverParamsBuilder
WasmDisassemblyChunk
WasmDisassemblyChunkBuilder

Enums

ScriptLanguage
Enum of possible script languages.

Type Aliases

BreakpointId
Breakpoint identifier.
CallFrameId
Call frame identifier.