CallFrameBuilder

Struct CallFrameBuilder 

pub struct CallFrameBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> CallFrameBuilder<'a>

pub fn function_location(self, function_location: Location<'a>) -> Self

Location in the source code.

pub fn return_value(self, return_value: RemoteObject<'a>) -> Self

The value being returned, if the function is at return point.

pub fn can_be_restarted(self, can_be_restarted: bool) -> Self

Valid only while the VM is paused and indicates whether this frame can be restarted or not. Note that a ‘true’ value here does not guarantee that Debugger#restartFrame with this CallFrameId will be successful, but it is very likely.

pub fn build(self) -> CallFrame<'a>