pub struct EnableReturns<'a> { /* private fields */ }Expand description
Enables debugger for the given page. Clients should not assume that the debugging has been enabled until the result for this command is received.
Implementations
Sourceimpl<'a> EnableReturns<'a>
impl<'a> EnableReturns<'a>
Sourcepub fn builder(debugger_id: UniqueDebuggerId<'a>) -> EnableReturnsBuilder<'a>
pub fn builder(debugger_id: UniqueDebuggerId<'a>) -> EnableReturnsBuilder<'a>
Creates a builder for this type with the required parameters:
debugger_id: Unique identifier of the debugger.
Sourcepub fn debugger_id(&self) -> &UniqueDebuggerId<'a>
pub fn debugger_id(&self) -> &UniqueDebuggerId<'a>
Unique identifier of the debugger.