pub struct EvaluateOnCallFrameParams {
pub callFrameId: CallFrameId,
pub expression: String,
pub objectGroup: Option<String>,
pub includeCommandLineAPI: Option<bool>,
pub silent: Option<bool>,
pub returnByValue: Option<bool>,
pub generatePreview: Option<bool>,
pub throwOnSideEffect: Option<bool>,
pub timeout: Option<TimeDelta>,
}Expand description
Evaluates expression on a given call frame.
Fields
callFrameId: CallFrameIdCall frame identifier to evaluate on.
expression: StringExpression to evaluate.
objectGroup: Option<String>String object group name to put result into (allows rapid releasing resulting object handles using ‘releaseObjectGroup’).
includeCommandLineAPI: Option<bool>Specifies whether command line API should be available to the evaluated expression, defaults to false.
silent: Option<bool>In silent mode exceptions thrown during evaluation are not reported and do not pause execution. Overrides ‘setPauseOnException’ state.
returnByValue: Option<bool>Whether the result is expected to be a JSON object that should be sent by value.
generatePreview: Option<bool>Whether preview should be generated for the result.
throwOnSideEffect: Option<bool>Whether to throw an exception if side effect cannot be ruled out during evaluation.
timeout: Option<TimeDelta>Terminate execution after timing out (number of milliseconds).
Implementations