EvaluateOnCallFrameParamsBuilder

Struct EvaluateOnCallFrameParamsBuilder 

pub struct EvaluateOnCallFrameParamsBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> EvaluateOnCallFrameParamsBuilder<'a>

pub fn object_group(self, object_group: impl Into<Cow<'a, str>>) -> Self

String object group name to put result into (allows rapid releasing resulting object handles using ‘releaseObjectGroup’).

pub fn include_command_line_api(self, include_command_line_api: bool) -> Self

Specifies whether command line API should be available to the evaluated expression, defaults to false.

pub fn silent(self, silent: bool) -> Self

In silent mode exceptions thrown during evaluation are not reported and do not pause execution. Overrides ‘setPauseOnException’ state.

pub fn return_by_value(self, return_by_value: bool) -> Self

Whether the result is expected to be a JSON object that should be sent by value.

pub fn generate_preview(self, generate_preview: bool) -> Self

Whether preview should be generated for the result.

pub fn throw_on_side_effect(self, throw_on_side_effect: bool) -> Self

Whether to throw an exception if side effect cannot be ruled out during evaluation.

pub fn timeout(self, timeout: TimeDelta) -> Self

Terminate execution after timing out (number of milliseconds).

pub fn build(self) -> EvaluateOnCallFrameParams<'a>