pub struct GetPossibleBreakpointsParamsBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> GetPossibleBreakpointsParamsBuilder<'a>
impl<'a> GetPossibleBreakpointsParamsBuilder<'a>
Sourcepub fn end(self, end: Location<'a>) -> Self
pub fn end(self, end: Location<'a>) -> Self
End of range to search possible breakpoint locations in (excluding). When not specified, end of scripts is used as end of range.
Sourcepub fn restrict_to_function(self, restrict_to_function: bool) -> Self
pub fn restrict_to_function(self, restrict_to_function: bool) -> Self
Only consider locations which are in the same (non-nested) function as start.
pub fn build(self) -> GetPossibleBreakpointsParams<'a>