pub struct GetPossibleBreakpointsReturns<'a> { /* private fields */ }Expand description
Returns possible locations for breakpoint. scriptId in start and end range locations should be the same.
Implementations
Sourceimpl<'a> GetPossibleBreakpointsReturns<'a>
impl<'a> GetPossibleBreakpointsReturns<'a>
Sourcepub fn builder(
locations: Vec<BreakLocation<'a>>,
) -> GetPossibleBreakpointsReturnsBuilder<'a>
pub fn builder( locations: Vec<BreakLocation<'a>>, ) -> GetPossibleBreakpointsReturnsBuilder<'a>
Creates a builder for this type with the required parameters:
locations: List of the possible breakpoint locations.
Sourcepub fn locations(&self) -> &[BreakLocation<'a>]
pub fn locations(&self) -> &[BreakLocation<'a>]
List of the possible breakpoint locations.