NextWasmDisassemblyChunkParams

Struct NextWasmDisassemblyChunkParams 

pub struct NextWasmDisassemblyChunkParams<'a> { /* private fields */ }
Disassemble the next chunk of lines for the module corresponding to the stream. If disassembly is complete, this API will invalidate the streamId and return an empty chunk. Any subsequent calls for the now invalid stream will return errors.

Implementations

Source

impl<'a> NextWasmDisassemblyChunkParams<'a>

pub fn builder( stream_id: impl Into<Cow<'a, str>>, ) -> NextWasmDisassemblyChunkParamsBuilder<'a>

Creates a builder for this type with the required parameters:

  • stream_id:
pub fn stream_id(&self) -> &str

Source

impl<'a> NextWasmDisassemblyChunkParams<'a>

pub const METHOD: &'static str = "Debugger.nextWasmDisassemblyChunk"