ResumeParamsBuilder

Struct ResumeParamsBuilder 

pub struct ResumeParamsBuilder { /* private fields */ }

Implementations

Source

impl ResumeParamsBuilder

pub fn terminate_on_resume(self, terminate_on_resume: bool) -> Self

Set to true to terminate execution upon resuming execution. In contrast to Runtime.terminateExecution, this will allows to execute further JavaScript (i.e. via evaluation) until execution of the paused code is actually resumed, at which point termination is triggered. If execution is currently not paused, this parameter has no effect.

pub fn build(self) -> ResumeParams