pub struct Scope<'a> { /* private fields */ }Expand description
Scope description.
Implementations
Sourceimpl<'a> Scope<'a>
impl<'a> Scope<'a>
Sourcepub fn builder(
type_: impl Into<Cow<'a, str>>,
object: RemoteObject<'a>,
) -> ScopeBuilder<'a>
pub fn builder( type_: impl Into<Cow<'a, str>>, object: RemoteObject<'a>, ) -> ScopeBuilder<'a>
Creates a builder for this type with the required parameters:
type_: Scope type.object: Object representing the scope. Forglobalandwithscopes it represents the actual object; for the rest of the scopes, it is artificial transient object enumerating scope variables as its properties.
Sourcepub fn object(&self) -> &RemoteObject<'a>
pub fn object(&self) -> &RemoteObject<'a>
Object representing the scope. For ‘global’ and ‘with’ scopes it represents the actual object; for the rest of the scopes, it is artificial transient object enumerating scope variables as its properties.
pub fn name(&self) -> Option<&str>
Sourcepub fn start_location(&self) -> Option<&Location<'a>>
pub fn start_location(&self) -> Option<&Location<'a>>
Location in the source code where scope starts
Sourcepub fn end_location(&self) -> Option<&Location<'a>>
pub fn end_location(&self) -> Option<&Location<'a>>
Location in the source code where scope ends