pub struct SetBlackboxExecutionContextsParams<'a> { /* private fields */ }Expand description
Replace previous blackbox execution contexts with passed ones. Forces backend to skip stepping/pausing in scripts in these execution contexts. VM will try to leave blackboxed script by performing ‘step in’ several times, finally resorting to ‘step out’ if unsuccessful.
Implementations
Sourceimpl<'a> SetBlackboxExecutionContextsParams<'a>
impl<'a> SetBlackboxExecutionContextsParams<'a>
Sourcepub fn builder(
unique_ids: Vec<Cow<'a, str>>,
) -> SetBlackboxExecutionContextsParamsBuilder<'a>
pub fn builder( unique_ids: Vec<Cow<'a, str>>, ) -> SetBlackboxExecutionContextsParamsBuilder<'a>
Creates a builder for this type with the required parameters:
unique_ids: Array of execution context unique ids for the debugger to ignore.
Sourcepub fn unique_ids(&self) -> &[Cow<'a, str>]
pub fn unique_ids(&self) -> &[Cow<'a, str>]
Array of execution context unique ids for the debugger to ignore.