pub struct SetBlackboxPatternsParams<'a> { /* private fields */ }Expand description
Replace previous blackbox patterns with passed ones. Forces backend to skip stepping/pausing in scripts with url matching one of the patterns. VM will try to leave blackboxed script by performing ‘step in’ several times, finally resorting to ‘step out’ if unsuccessful.
Implementations
Sourceimpl<'a> SetBlackboxPatternsParams<'a>
impl<'a> SetBlackboxPatternsParams<'a>
Sourcepub fn builder(
patterns: Vec<Cow<'a, str>>,
) -> SetBlackboxPatternsParamsBuilder<'a>
pub fn builder( patterns: Vec<Cow<'a, str>>, ) -> SetBlackboxPatternsParamsBuilder<'a>
Creates a builder for this type with the required parameters:
patterns: Array of regexps that will be used to check script url for blackbox state.
Sourcepub fn patterns(&self) -> &[Cow<'a, str>]
pub fn patterns(&self) -> &[Cow<'a, str>]
Array of regexps that will be used to check script url for blackbox state.
Sourcepub fn skip_anonymous(&self) -> Option<bool>
pub fn skip_anonymous(&self) -> Option<bool>
If true, also ignore scripts with no source url.