pub struct SetBlackboxedRangesParams<'a> { /* private fields */ }Expand description
Makes backend skip steps in the script in blackboxed ranges. VM will try leave blacklisted scripts by performing ‘step in’ several times, finally resorting to ‘step out’ if unsuccessful. Positions array contains positions where blackbox state is changed. First interval isn’t blackboxed. Array should be sorted.
Implementations
Sourceimpl<'a> SetBlackboxedRangesParams<'a>
impl<'a> SetBlackboxedRangesParams<'a>
Sourcepub fn builder(
script_id: ScriptId<'a>,
positions: Vec<ScriptPosition>,
) -> SetBlackboxedRangesParamsBuilder<'a>
pub fn builder( script_id: ScriptId<'a>, positions: Vec<ScriptPosition>, ) -> SetBlackboxedRangesParamsBuilder<'a>
Creates a builder for this type with the required parameters:
script_id: Id of the script.positions:
pub fn positions(&self) -> &[ScriptPosition]