pub struct SetBreakpointByUrlParams<'a> { /* private fields */ }Expand description
Sets JavaScript breakpoint at given location specified either by URL or URL regex. Once this command is issued, all existing parsed scripts will have breakpoints resolved and returned in ‘locations’ property. Further matching script parsing will result in subsequent ‘breakpointResolved’ events issued. This logical breakpoint will survive page reloads.
Implementations
Sourceimpl<'a> SetBreakpointByUrlParams<'a>
impl<'a> SetBreakpointByUrlParams<'a>
Sourcepub fn builder(line_number: i64) -> SetBreakpointByUrlParamsBuilder<'a>
pub fn builder(line_number: i64) -> SetBreakpointByUrlParamsBuilder<'a>
Creates a builder for this type with the required parameters:
line_number: Line number to set breakpoint at.
Sourcepub fn line_number(&self) -> i64
pub fn line_number(&self) -> i64
Line number to set breakpoint at.
Sourcepub fn url_regex(&self) -> Option<&str>
pub fn url_regex(&self) -> Option<&str>
Regex pattern for the URLs of the resources to set breakpoints on. Either ‘url’ or ‘urlRegex’ must be specified.
Sourcepub fn script_hash(&self) -> Option<&str>
pub fn script_hash(&self) -> Option<&str>
Script hash of the resources to set breakpoint on.
Sourcepub fn column_number(&self) -> Option<i64>
pub fn column_number(&self) -> Option<i64>
Offset in the line to set breakpoint at.