pub struct SetBreakpointByUrlParamsBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> SetBreakpointByUrlParamsBuilder<'a>
impl<'a> SetBreakpointByUrlParamsBuilder<'a>
Sourcepub fn url(self, url: impl Into<Cow<'a, str>>) -> Self
pub fn url(self, url: impl Into<Cow<'a, str>>) -> Self
URL of the resources to set breakpoint on.
Sourcepub fn url_regex(self, url_regex: impl Into<Cow<'a, str>>) -> Self
pub fn url_regex(self, url_regex: impl Into<Cow<'a, str>>) -> Self
Regex pattern for the URLs of the resources to set breakpoints on. Either ‘url’ or ‘urlRegex’ must be specified.
Sourcepub fn script_hash(self, script_hash: impl Into<Cow<'a, str>>) -> Self
pub fn script_hash(self, script_hash: impl Into<Cow<'a, str>>) -> Self
Script hash of the resources to set breakpoint on.
Sourcepub fn column_number(self, column_number: i64) -> Self
pub fn column_number(self, column_number: i64) -> Self
Offset in the line to set breakpoint at.
Sourcepub fn condition(self, condition: impl Into<Cow<'a, str>>) -> Self
pub fn condition(self, condition: impl Into<Cow<'a, str>>) -> Self
Expression to use as a breakpoint condition. When specified, debugger will only stop on the breakpoint if this expression evaluates to true.
pub fn build(self) -> SetBreakpointByUrlParams<'a>