SetBreakpointByUrlReturns

Struct SetBreakpointByUrlReturns 

pub struct SetBreakpointByUrlReturns<'a> { /* private fields */ }
Sets JavaScript breakpoint at given location specified either by URL or URL regex. Once this command is issued, all existing parsed scripts will have breakpoints resolved and returned in ‘locations’ property. Further matching script parsing will result in subsequent ‘breakpointResolved’ events issued. This logical breakpoint will survive page reloads.

Implementations

Source

impl<'a> SetBreakpointByUrlReturns<'a>

pub fn builder( breakpoint_id: impl Into<BreakpointId<'a>>, locations: Vec<Location<'a>>, ) -> SetBreakpointByUrlReturnsBuilder<'a>

Creates a builder for this type with the required parameters:

  • breakpoint_id: Id of the created breakpoint for further reference.
  • locations: List of the locations this breakpoint resolved into upon addition.
pub fn breakpoint_id(&self) -> &BreakpointId<'a>

Id of the created breakpoint for further reference.

pub fn locations(&self) -> &[Location<'a>]

List of the locations this breakpoint resolved into upon addition.