pub struct SetBreakpointOnFunctionCallReturns<'a> { /* private fields */ }Expand description
Sets JavaScript breakpoint before each call to the given function. If another function was created from the same source as a given one, calling it will also trigger the breakpoint.
Implementations
Sourceimpl<'a> SetBreakpointOnFunctionCallReturns<'a>
impl<'a> SetBreakpointOnFunctionCallReturns<'a>
Sourcepub fn builder(
breakpoint_id: impl Into<BreakpointId<'a>>,
) -> SetBreakpointOnFunctionCallReturnsBuilder<'a>
pub fn builder( breakpoint_id: impl Into<BreakpointId<'a>>, ) -> SetBreakpointOnFunctionCallReturnsBuilder<'a>
Creates a builder for this type with the required parameters:
breakpoint_id: Id of the created breakpoint for further reference.
Sourcepub fn breakpoint_id(&self) -> &BreakpointId<'a>
pub fn breakpoint_id(&self) -> &BreakpointId<'a>
Id of the created breakpoint for further reference.