pub struct SetScriptSourceParams<'a> { /* private fields */ }Expand description
Edits JavaScript source live.
In general, functions that are currently on the stack can not be edited with a single exception: If the edited function is the top-most stack frame and that is the only activation of that function on the stack. In this case the live edit will be successful and a ‘Debugger.restartFrame’ for the top-most function is automatically triggered.
Implementations
Sourceimpl<'a> SetScriptSourceParams<'a>
impl<'a> SetScriptSourceParams<'a>
Sourcepub fn builder(
script_id: ScriptId<'a>,
script_source: impl Into<Cow<'a, str>>,
) -> SetScriptSourceParamsBuilder<'a>
pub fn builder( script_id: ScriptId<'a>, script_source: impl Into<Cow<'a, str>>, ) -> SetScriptSourceParamsBuilder<'a>
Creates a builder for this type with the required parameters:
script_id: Id of the script to edit.script_source: New content of the script.
Sourcepub fn script_source(&self) -> &str
pub fn script_source(&self) -> &str
New content of the script.
Sourcepub fn dry_run(&self) -> Option<bool>
pub fn dry_run(&self) -> Option<bool>
If true the change will not actually be applied. Dry run may be used to get result description without actually modifying the code.
Sourcepub fn allow_top_frame_editing(&self) -> Option<bool>
pub fn allow_top_frame_editing(&self) -> Option<bool>
If true, then ‘scriptSource’ is allowed to change the function on top of the stack as long as the top-most stack frame is the only activation of that function.