SetScriptSourceReturns

Struct SetScriptSourceReturns 

pub struct SetScriptSourceReturns<'a> { /* private fields */ }
Edits JavaScript source live.

In general, functions that are currently on the stack can not be edited with a single exception: If the edited function is the top-most stack frame and that is the only activation of that function on the stack. In this case the live edit will be successful and a ‘Debugger.restartFrame’ for the top-most function is automatically triggered.

Implementations

Source

impl<'a> SetScriptSourceReturns<'a>

pub fn builder( status: impl Into<Cow<'a, str>>, ) -> SetScriptSourceReturnsBuilder<'a>

Creates a builder for this type with the required parameters:

  • status: Whether the operation was successful or not. Only Ok denotes a successful live edit while the other enum variants denote why the live edit failed.
pub fn call_frames(&self) -> Option<&[CallFrame<'a>]>

New stack trace in case editing has happened while VM was stopped.

pub fn stack_changed(&self) -> Option<bool>

Whether current call stack was modified after applying the changes.

pub fn async_stack_trace(&self) -> Option<&StackTrace<'a>>

Async stack trace, if any.

pub fn async_stack_trace_id(&self) -> Option<&StackTraceId<'a>>

Async stack trace, if any.

pub fn status(&self) -> &str

Whether the operation was successful or not. Only ‘Ok’ denotes a successful live edit while the other enum variants denote why the live edit failed.

pub fn exception_details(&self) -> Option<&ExceptionDetails<'a>>

Exception details if any. Only present when ‘status’ is ‘CompileError’.