pub struct SetScriptSourceReturnsBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> SetScriptSourceReturnsBuilder<'a>
impl<'a> SetScriptSourceReturnsBuilder<'a>
Sourcepub fn call_frames(self, call_frames: Vec<CallFrame<'a>>) -> Self
pub fn call_frames(self, call_frames: Vec<CallFrame<'a>>) -> Self
New stack trace in case editing has happened while VM was stopped.
Sourcepub fn stack_changed(self, stack_changed: bool) -> Self
pub fn stack_changed(self, stack_changed: bool) -> Self
Whether current call stack was modified after applying the changes.
Sourcepub fn async_stack_trace(self, async_stack_trace: StackTrace<'a>) -> Self
pub fn async_stack_trace(self, async_stack_trace: StackTrace<'a>) -> Self
Async stack trace, if any.
Sourcepub fn async_stack_trace_id(
self,
async_stack_trace_id: StackTraceId<'a>,
) -> Self
pub fn async_stack_trace_id( self, async_stack_trace_id: StackTraceId<'a>, ) -> Self
Async stack trace, if any.
Sourcepub fn exception_details(self, exception_details: ExceptionDetails<'a>) -> Self
pub fn exception_details(self, exception_details: ExceptionDetails<'a>) -> Self
Exception details if any. Only present when ‘status’ is ‘CompileError’.
pub fn build(self) -> SetScriptSourceReturns<'a>