StepIntoParamsBuilder

Struct StepIntoParamsBuilder 

pub struct StepIntoParamsBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> StepIntoParamsBuilder<'a>

pub fn break_on_async_call(self, break_on_async_call: bool) -> Self

Debugger will pause on the execution of the first async task which was scheduled before next pause.

pub fn skip_list(self, skip_list: Vec<LocationRange<'a>>) -> Self

The skipList specifies location ranges that should be skipped on step into.

pub fn build(self) -> StepIntoParams<'a>