pub struct AddInspectedHeapObjectParams {
pub heapObjectId: HeapSnapshotObjectId,
}Expand description
Enables console to refer to the node with given id via $x (see Command Line API for more details $x functions).
Fields
heapObjectId: HeapSnapshotObjectIdHeap snapshot object id to be accessible by means of $x command line API.
Implementations