pub struct GetHeapObjectIdReturns<'a> { /* private fields */ }Implementations
Sourceimpl<'a> GetHeapObjectIdReturns<'a>
impl<'a> GetHeapObjectIdReturns<'a>
Sourcepub fn builder(
heap_snapshot_object_id: impl Into<HeapSnapshotObjectId<'a>>,
) -> GetHeapObjectIdReturnsBuilder<'a>
pub fn builder( heap_snapshot_object_id: impl Into<HeapSnapshotObjectId<'a>>, ) -> GetHeapObjectIdReturnsBuilder<'a>
Creates a builder for this type with the required parameters:
heap_snapshot_object_id: Id of the heap snapshot object corresponding to the passed remote object id.
Sourcepub fn heap_snapshot_object_id(&self) -> &HeapSnapshotObjectId<'a>
pub fn heap_snapshot_object_id(&self) -> &HeapSnapshotObjectId<'a>
Id of the heap snapshot object corresponding to the passed remote object id.