pub struct GetObjectByHeapObjectIdParams<'a> { /* private fields */ }Implementations
Sourceimpl<'a> GetObjectByHeapObjectIdParams<'a>
impl<'a> GetObjectByHeapObjectIdParams<'a>
Sourcepub fn builder(
object_id: impl Into<HeapSnapshotObjectId<'a>>,
) -> GetObjectByHeapObjectIdParamsBuilder<'a>
pub fn builder( object_id: impl Into<HeapSnapshotObjectId<'a>>, ) -> GetObjectByHeapObjectIdParamsBuilder<'a>
Creates a builder for this type with the required parameters:
object_id:
pub fn object_id(&self) -> &HeapSnapshotObjectId<'a>
Sourcepub fn object_group(&self) -> Option<&str>
pub fn object_group(&self) -> Option<&str>
Symbolic group name that can be used to release multiple objects.