pub struct SamplingHeapProfileNode<'a> { /* private fields */ }Expand description
Sampling Heap Profile node. Holds callsite information, allocation statistics and child nodes.
Implementations
Sourceimpl<'a> SamplingHeapProfileNode<'a>
impl<'a> SamplingHeapProfileNode<'a>
Sourcepub fn builder(
call_frame: CallFrame<'a>,
self_size: f64,
id: u64,
children: Vec<Box<SamplingHeapProfileNode<'a>>>,
) -> SamplingHeapProfileNodeBuilder<'a>
pub fn builder( call_frame: CallFrame<'a>, self_size: f64, id: u64, children: Vec<Box<SamplingHeapProfileNode<'a>>>, ) -> SamplingHeapProfileNodeBuilder<'a>
Creates a builder for this type with the required parameters:
call_frame: Function location.self_size: Allocations size in bytes for the node excluding children.id: Node id. Ids are unique across all profiles collected between startSampling and stopSampling.children: Child nodes.
Sourcepub fn call_frame(&self) -> &CallFrame<'a>
pub fn call_frame(&self) -> &CallFrame<'a>
Function location.
Sourcepub fn id(&self) -> u64
pub fn id(&self) -> u64
Node id. Ids are unique across all profiles collected between startSampling and stopSampling.
Sourcepub fn children(&self) -> &[Box<SamplingHeapProfileNode<'a>>]
pub fn children(&self) -> &[Box<SamplingHeapProfileNode<'a>>]
Child nodes.