pub struct StartSamplingParams {
pub samplingInterval: Option<f64>,
pub stackDepth: Option<f64>,
pub includeObjectsCollectedByMajorGC: Option<bool>,
pub includeObjectsCollectedByMinorGC: Option<bool>,
}Fields
samplingInterval: Option<f64>Average sample interval in bytes. Poisson distribution is used for the intervals. The default value is 32768 bytes.
stackDepth: Option<f64>Maximum stack depth. The default value is 128.
includeObjectsCollectedByMajorGC: Option<bool>By default, the sampling heap profiler reports only objects which are still alive when the profile is returned via getSamplingProfile or stopSampling, which is useful for determining what functions contribute the most to steady-state memory usage. This flag instructs the sampling heap profiler to also include information about objects discarded by major GC, which will show which functions cause large temporary memory usage or long GC pauses.
includeObjectsCollectedByMinorGC: Option<bool>By default, the sampling heap profiler reports only objects which are still alive when the profile is returned via getSamplingProfile or stopSampling, which is useful for determining what functions contribute the most to steady-state memory usage. This flag instructs the sampling heap profiler to also include information about objects discarded by minor GC, which is useful when tuning a latency-sensitive application for minimal GC activity.