StartSamplingParamsBuilder

Struct StartSamplingParamsBuilder 

pub struct StartSamplingParamsBuilder { /* private fields */ }

Implementations

Source

impl StartSamplingParamsBuilder

pub fn sampling_interval(self, sampling_interval: f64) -> Self

Average sample interval in bytes. Poisson distribution is used for the intervals. The default value is 32768 bytes.

pub fn stack_depth(self, stack_depth: f64) -> Self

Maximum stack depth. The default value is 128.

pub fn include_objects_collected_by_major_gc( self, include_objects_collected_by_major_gc: bool, ) -> Self

By default, the sampling heap profiler reports only objects which are still alive when the profile is returned via getSamplingProfile or stopSampling, which is useful for determining what functions contribute the most to steady-state memory usage. This flag instructs the sampling heap profiler to also include information about objects discarded by major GC, which will show which functions cause large temporary memory usage or long GC pauses.

pub fn include_objects_collected_by_minor_gc( self, include_objects_collected_by_minor_gc: bool, ) -> Self

By default, the sampling heap profiler reports only objects which are still alive when the profile is returned via getSamplingProfile or stopSampling, which is useful for determining what functions contribute the most to steady-state memory usage. This flag instructs the sampling heap profiler to also include information about objects discarded by minor GC, which is useful when tuning a latency-sensitive application for minimal GC activity.

pub fn build(self) -> StartSamplingParams