pub struct StopTrackingHeapObjectsParams { /* private fields */ }Implementations
Sourceimpl StopTrackingHeapObjectsParams
impl StopTrackingHeapObjectsParams
Sourcepub fn builder() -> StopTrackingHeapObjectsParamsBuilder
pub fn builder() -> StopTrackingHeapObjectsParamsBuilder
Creates a builder for this type.
Sourcepub fn report_progress(&self) -> Option<bool>
pub fn report_progress(&self) -> Option<bool>
If true ‘reportHeapSnapshotProgress’ events will be generated while snapshot is being taken when the tracking is stopped.
Sourcepub fn treat_global_objects_as_roots(&self) -> Option<bool>
pub fn treat_global_objects_as_roots(&self) -> Option<bool>
Deprecated in favor of ‘exposeInternals’.
Sourcepub fn capture_numeric_value(&self) -> Option<bool>
pub fn capture_numeric_value(&self) -> Option<bool>
If true, numerical values are included in the snapshot
Sourcepub fn expose_internals(&self) -> Option<bool>
pub fn expose_internals(&self) -> Option<bool>
If true, exposes internals of the snapshot.