pub struct StopTrackingHeapObjectsParamsBuilder { /* private fields */ }Implementations
Sourceimpl StopTrackingHeapObjectsParamsBuilder
impl StopTrackingHeapObjectsParamsBuilder
Sourcepub fn report_progress(self, report_progress: bool) -> Self
pub fn report_progress(self, report_progress: bool) -> Self
If true ‘reportHeapSnapshotProgress’ events will be generated while snapshot is being taken when the tracking is stopped.
Sourcepub fn treat_global_objects_as_roots(
self,
treat_global_objects_as_roots: bool,
) -> Self
pub fn treat_global_objects_as_roots( self, treat_global_objects_as_roots: bool, ) -> Self
Deprecated in favor of ‘exposeInternals’.
Sourcepub fn capture_numeric_value(self, capture_numeric_value: bool) -> Self
pub fn capture_numeric_value(self, capture_numeric_value: bool) -> Self
If true, numerical values are included in the snapshot
Sourcepub fn expose_internals(self, expose_internals: bool) -> Self
pub fn expose_internals(self, expose_internals: bool) -> Self
If true, exposes internals of the snapshot.
pub fn build(self) -> StopTrackingHeapObjectsParams