pub struct TakeHeapSnapshotParams {
pub reportProgress: Option<bool>,
pub treatGlobalObjectsAsRoots: Option<bool>,
pub captureNumericValue: Option<bool>,
pub exposeInternals: Option<bool>,
}Fields
reportProgress: Option<bool>If true ‘reportHeapSnapshotProgress’ events will be generated while snapshot is being taken.
treatGlobalObjectsAsRoots: Option<bool>If true, a raw snapshot without artificial roots will be generated. Deprecated in favor of ‘exposeInternals’.
captureNumericValue: Option<bool>If true, numerical values are included in the snapshot
exposeInternals: Option<bool>If true, exposes internals of the snapshot.
Implementations