pub struct GetBestEffortCoverageReturns<'a> { /* private fields */ }Expand description
Collect coverage data for the current isolate. The coverage data may be incomplete due to garbage collection.
Implementations
Sourceimpl<'a> GetBestEffortCoverageReturns<'a>
impl<'a> GetBestEffortCoverageReturns<'a>
Sourcepub fn builder(
result: Vec<ScriptCoverage<'a>>,
) -> GetBestEffortCoverageReturnsBuilder<'a>
pub fn builder( result: Vec<ScriptCoverage<'a>>, ) -> GetBestEffortCoverageReturnsBuilder<'a>
Creates a builder for this type with the required parameters:
result: Coverage data for the current isolate.
Sourcepub fn result(&self) -> &[ScriptCoverage<'a>]
pub fn result(&self) -> &[ScriptCoverage<'a>]
Coverage data for the current isolate.