pub struct Profile<'a> { /* private fields */ }Expand description
Profile.
Implementations
Sourceimpl<'a> Profile<'a>
impl<'a> Profile<'a>
Sourcepub fn builder(
nodes: Vec<ProfileNode<'a>>,
start_time: f64,
end_time: f64,
) -> ProfileBuilder<'a>
pub fn builder( nodes: Vec<ProfileNode<'a>>, start_time: f64, end_time: f64, ) -> ProfileBuilder<'a>
Creates a builder for this type with the required parameters:
nodes: The list of profile nodes. First item is the root node.start_time: Profiling start timestamp in microseconds.end_time: Profiling end timestamp in microseconds.
Sourcepub fn nodes(&self) -> &[ProfileNode<'a>]
pub fn nodes(&self) -> &[ProfileNode<'a>]
The list of profile nodes. First item is the root node.
Sourcepub fn start_time(&self) -> f64
pub fn start_time(&self) -> f64
Profiling start timestamp in microseconds.
Sourcepub fn time_deltas(&self) -> Option<&[i64]>
pub fn time_deltas(&self) -> Option<&[i64]>
Time intervals between adjacent samples in microseconds. The first delta is relative to the profile startTime.