pub struct ProfileNode<'a> { /* private fields */ }Expand description
Profile node. Holds callsite information, execution statistics and child nodes.
Implementations
Sourceimpl<'a> ProfileNode<'a>
impl<'a> ProfileNode<'a>
Sourcepub fn builder(id: u64, call_frame: CallFrame<'a>) -> ProfileNodeBuilder<'a>
pub fn builder(id: u64, call_frame: CallFrame<'a>) -> ProfileNodeBuilder<'a>
Creates a builder for this type with the required parameters:
id: Unique id of the node.call_frame: Function location.
Sourcepub fn call_frame(&self) -> &CallFrame<'a>
pub fn call_frame(&self) -> &CallFrame<'a>
Function location.
Sourcepub fn hit_count(&self) -> Option<u64>
pub fn hit_count(&self) -> Option<u64>
Number of samples where this node was on top of the call stack.
Sourcepub fn deopt_reason(&self) -> Option<&str>
pub fn deopt_reason(&self) -> Option<&str>
The reason of being not optimized. The function may be deoptimized or marked as don’t optimize.
Sourcepub fn position_ticks(&self) -> Option<&[PositionTickInfo]>
pub fn position_ticks(&self) -> Option<&[PositionTickInfo]>
An array of source position ticks.