pub struct ProfileNodeBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> ProfileNodeBuilder<'a>
impl<'a> ProfileNodeBuilder<'a>
Sourcepub fn hit_count(self, hit_count: u64) -> Self
pub fn hit_count(self, hit_count: u64) -> Self
Number of samples where this node was on top of the call stack.
Sourcepub fn deopt_reason(self, deopt_reason: impl Into<Cow<'a, str>>) -> Self
pub fn deopt_reason(self, deopt_reason: impl Into<Cow<'a, str>>) -> Self
The reason of being not optimized. The function may be deoptimized or marked as don’t optimize.
Sourcepub fn position_ticks(self, position_ticks: Vec<PositionTickInfo>) -> Self
pub fn position_ticks(self, position_ticks: Vec<PositionTickInfo>) -> Self
An array of source position ticks.
pub fn build(self) -> ProfileNode<'a>