StartPreciseCoverageParams

Struct StartPreciseCoverageParams 

pub struct StartPreciseCoverageParams { /* private fields */ }
Enable precise code coverage. Coverage data for JavaScript executed before enabling precise code coverage may be incomplete. Enabling prevents running optimized code and resets execution counters.

Implementations

Source

impl StartPreciseCoverageParams

pub fn builder() -> StartPreciseCoverageParamsBuilder

Creates a builder for this type.

pub fn call_count(&self) -> Option<bool>

Collect accurate call counts beyond simple ‘covered’ or ‘not covered’.

pub fn detailed(&self) -> Option<bool>

Collect block-based coverage.

pub fn allow_triggered_updates(&self) -> Option<bool>

Allow the backend to send updates on its own initiative

Source

impl StartPreciseCoverageParams

pub const METHOD: &'static str = "Profiler.startPreciseCoverage"