pub struct TakePreciseCoverageReturns {
pub result: Vec<ScriptCoverage>,
pub timestamp: f64,
}Expand description
Collect coverage data for the current isolate, and resets execution counters. Precise code coverage needs to have started.
Fields
result: Vec<ScriptCoverage>Coverage data for the current isolate.
timestamp: f64Monotonically increasing time (in seconds) when the coverage update was taken in the backend.