Module runtime

Module runtime 

Runtime domain exposes JavaScript runtime by means of remote evaluation and mirror objects. Evaluation results are returned as mirror object that expose object type, string representation and unique identifier that can be used for further object reference. Original objects are maintained in memory unless they are either explicitly released or are released along with the other objects in their object group.

Structs

AddBindingParams
If executionContextId is empty, adds binding with the given name on the global objects of all inspected contexts, including those created later, bindings survive reloads. Binding function takes exactly one argument, this argument should be string, in case of any other input, function throws an exception. Each binding function call produces Runtime.bindingCalled notification.
AddBindingParamsBuilder
AwaitPromiseParams
Add handler to promise with given promise object id.
AwaitPromiseParamsBuilder
AwaitPromiseReturns
Add handler to promise with given promise object id.
AwaitPromiseReturnsBuilder
CallArgument
Represents function call argument. Either remote object id ‘objectId’, primitive ‘value’, unserializable primitive value or neither of (for undefined) them should be specified.
CallArgumentBuilder
CallFrame
Stack entry for runtime errors and assertions.
CallFrameBuilder
CallFunctionOnParams
Calls function with given declaration on the given object. Object group of the result is inherited from the target object.
CallFunctionOnParamsBuilder
CallFunctionOnReturns
Calls function with given declaration on the given object. Object group of the result is inherited from the target object.
CallFunctionOnReturnsBuilder
CompileScriptParams
Compiles expression.
CompileScriptParamsBuilder
CompileScriptReturns
Compiles expression.
CompileScriptReturnsBuilder
CustomPreview
CustomPreviewBuilder
DeepSerializedValue
Represents deep serialized value.
DeepSerializedValueBuilder
DisableParams
DiscardConsoleEntriesParams
EnableParams
EntryPreview
EntryPreviewBuilder
EvaluateParams
Evaluates expression on global object.
EvaluateParamsBuilder
EvaluateReturns
Evaluates expression on global object.
EvaluateReturnsBuilder
ExceptionDetails
Detailed information about exception (or error) that was thrown during script compilation or execution.
ExceptionDetailsBuilder
ExecutionContextDescription
Description of an isolated world.
ExecutionContextDescriptionBuilder
GetExceptionDetailsParams
This method tries to lookup and populate exception details for a JavaScript Error object. Note that the stackTrace portion of the resulting exceptionDetails will only be populated if the Runtime domain was enabled at the time when the Error was thrown.
GetExceptionDetailsParamsBuilder
GetExceptionDetailsReturns
This method tries to lookup and populate exception details for a JavaScript Error object. Note that the stackTrace portion of the resulting exceptionDetails will only be populated if the Runtime domain was enabled at the time when the Error was thrown.
GetExceptionDetailsReturnsBuilder
GetHeapUsageParams
GetHeapUsageReturns
Returns the JavaScript heap usage. It is the total usage of the corresponding isolate not scoped to a particular Runtime.
GetHeapUsageReturnsBuilder
GetIsolateIdParams
GetIsolateIdReturns
Returns the isolate id.
GetIsolateIdReturnsBuilder
GetPropertiesParams
Returns properties of a given object. Object group of the result is inherited from the target object.
GetPropertiesParamsBuilder
GetPropertiesReturns
Returns properties of a given object. Object group of the result is inherited from the target object.
GetPropertiesReturnsBuilder
GlobalLexicalScopeNamesParams
Returns all let, const and class variables from global scope.
GlobalLexicalScopeNamesParamsBuilder
GlobalLexicalScopeNamesReturns
Returns all let, const and class variables from global scope.
GlobalLexicalScopeNamesReturnsBuilder
InternalPropertyDescriptor
Object internal property descriptor. This property isn’t normally visible in JavaScript code.
InternalPropertyDescriptorBuilder
ObjectPreview
Object containing abbreviated remote object value.
ObjectPreviewBuilder
PrivatePropertyDescriptor
Object private field descriptor.
PrivatePropertyDescriptorBuilder
PropertyDescriptor
Object property descriptor.
PropertyDescriptorBuilder
PropertyPreview
PropertyPreviewBuilder
QueryObjectsParams
QueryObjectsParamsBuilder
QueryObjectsReturns
QueryObjectsReturnsBuilder
ReleaseObjectGroupParams
Releases all remote objects that belong to a given group.
ReleaseObjectGroupParamsBuilder
ReleaseObjectParams
Releases remote object with given id.
ReleaseObjectParamsBuilder
RemoteObject
Mirror object referencing original JavaScript object.
RemoteObjectBuilder
RemoveBindingParams
This method does not remove binding function from global object but unsubscribes current runtime agent from Runtime.bindingCalled notifications.
RemoveBindingParamsBuilder
RunIfWaitingForDebuggerParams
RunScriptParams
Runs script with given id in a given context.
RunScriptParamsBuilder
RunScriptReturns
Runs script with given id in a given context.
RunScriptReturnsBuilder
SerializationOptions
Represents options for serialization. Overrides ‘generatePreview’ and ‘returnByValue’.
SerializationOptionsBuilder
SetAsyncCallStackDepthParams
Enables or disables async call stacks tracking.
SetAsyncCallStackDepthParamsBuilder
SetCustomObjectFormatterEnabledParams
SetCustomObjectFormatterEnabledParamsBuilder
SetMaxCallStackSizeToCaptureParams
SetMaxCallStackSizeToCaptureParamsBuilder
StackTrace
Call frames for assertions or error messages.
StackTraceBuilder
StackTraceId
If ‘debuggerId’ is set stack trace comes from another debugger and can be resolved there. This allows to track cross-debugger calls. See ‘Runtime.StackTrace’ and ‘Debugger.paused’ for usages.
StackTraceIdBuilder
TerminateExecutionParams

Type Aliases

ExecutionContextId
Id of an execution context.
RemoteObjectId
Unique object identifier.
ScriptId
Unique script identifier.
TimeDelta
Number of milliseconds.
Timestamp
Number of milliseconds since epoch.
UniqueDebuggerId
Unique identifier of current debugger.
UnserializableValue
Primitive value which cannot be JSON-stringified. Includes values ‘-0’, ‘NaN’, ‘Infinity’, ‘-Infinity’, and bigint literals.