AddBindingParamsBuilder

Struct AddBindingParamsBuilder 

pub struct AddBindingParamsBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> AddBindingParamsBuilder<'a>

pub fn execution_context_id( self, execution_context_id: ExecutionContextId, ) -> Self

If specified, the binding would only be exposed to the specified execution context. If omitted and ‘executionContextName’ is not set, the binding is exposed to all execution contexts of the target. This parameter is mutually exclusive with ‘executionContextName’. Deprecated in favor of ‘executionContextName’ due to an unclear use case and bugs in implementation (crbug.com/1169639). ‘executionContextId’ will be removed in the future.

pub fn execution_context_name( self, execution_context_name: impl Into<Cow<'a, str>>, ) -> Self

If specified, the binding is exposed to the executionContext with matching name, even for contexts created after the binding is added. See also ‘ExecutionContext.name’ and ‘worldName’ parameter to ‘Page.addScriptToEvaluateOnNewDocument’. This parameter is mutually exclusive with ‘executionContextId’.

pub fn build(self) -> AddBindingParams<'a>