pub struct AwaitPromiseParams<'a> { /* private fields */ }Expand description
Add handler to promise with given promise object id.
Implementations
Sourceimpl<'a> AwaitPromiseParams<'a>
impl<'a> AwaitPromiseParams<'a>
Sourcepub fn builder(
promise_object_id: impl Into<RemoteObjectId<'a>>,
) -> AwaitPromiseParamsBuilder<'a>
pub fn builder( promise_object_id: impl Into<RemoteObjectId<'a>>, ) -> AwaitPromiseParamsBuilder<'a>
Creates a builder for this type with the required parameters:
promise_object_id: Identifier of the promise.
Sourcepub fn promise_object_id(&self) -> &RemoteObjectId<'a>
pub fn promise_object_id(&self) -> &RemoteObjectId<'a>
Identifier of the promise.
Sourcepub fn return_by_value(&self) -> Option<bool>
pub fn return_by_value(&self) -> Option<bool>
Whether the result is expected to be a JSON object that should be sent by value.
Sourcepub fn generate_preview(&self) -> Option<bool>
pub fn generate_preview(&self) -> Option<bool>
Whether preview should be generated for the result.