CallFunctionOnParamsBuilder

Struct CallFunctionOnParamsBuilder 

pub struct CallFunctionOnParamsBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> CallFunctionOnParamsBuilder<'a>

pub fn object_id(self, object_id: impl Into<RemoteObjectId<'a>>) -> Self

Identifier of the object to call function on. Either objectId or executionContextId should be specified.

pub fn arguments(self, arguments: Vec<CallArgument<'a>>) -> Self

Call arguments. All call arguments must belong to the same JavaScript world as the target object.

pub fn silent(self, silent: bool) -> Self

In silent mode exceptions thrown during evaluation are not reported and do not pause execution. Overrides ‘setPauseOnException’ state.

pub fn return_by_value(self, return_by_value: bool) -> Self

Whether the result is expected to be a JSON object which should be sent by value. Can be overriden by ‘serializationOptions’.

pub fn generate_preview(self, generate_preview: bool) -> Self

Whether preview should be generated for the result.

pub fn user_gesture(self, user_gesture: bool) -> Self

Whether execution should be treated as initiated by user in the UI.

pub fn await_promise(self, await_promise: bool) -> Self

Whether execution should ‘await’ for resulting value and return once awaited promise is resolved.

pub fn execution_context_id( self, execution_context_id: ExecutionContextId, ) -> Self

Specifies execution context which global object will be used to call function on. Either executionContextId or objectId should be specified.

pub fn object_group(self, object_group: impl Into<Cow<'a, str>>) -> Self

Symbolic group name that can be used to release multiple objects. If objectGroup is not specified and objectId is, objectGroup will be inherited from object.

pub fn throw_on_side_effect(self, throw_on_side_effect: bool) -> Self

Whether to throw an exception if side effect cannot be ruled out during evaluation.

pub fn unique_context_id( self, unique_context_id: impl Into<Cow<'a, str>>, ) -> Self

An alternative way to specify the execution context to call function on. Compared to contextId that may be reused across processes, this is guaranteed to be system-unique, so it can be used to prevent accidental function call in context different than intended (e.g. as a result of navigation across process boundaries). This is mutually exclusive with ‘executionContextId’.

pub fn serialization_options( self, serialization_options: SerializationOptions<'a>, ) -> Self

Specifies the result serialization. If provided, overrides ‘generatePreview’ and ‘returnByValue’.

pub fn build(self) -> CallFunctionOnParams<'a>