pub struct CompileScriptParams<'a> { /* private fields */ }Expand description
Compiles expression.
Implementations
Sourceimpl<'a> CompileScriptParams<'a>
impl<'a> CompileScriptParams<'a>
Sourcepub fn builder(
expression: impl Into<Cow<'a, str>>,
source_url: impl Into<Cow<'a, str>>,
persist_script: bool,
) -> CompileScriptParamsBuilder<'a>
pub fn builder( expression: impl Into<Cow<'a, str>>, source_url: impl Into<Cow<'a, str>>, persist_script: bool, ) -> CompileScriptParamsBuilder<'a>
Creates a builder for this type with the required parameters:
expression: Expression to compile.source_url: Source url to be set for the script.persist_script: Specifies whether the compiled script should be persisted.
Sourcepub fn expression(&self) -> &str
pub fn expression(&self) -> &str
Expression to compile.
Sourcepub fn source_url(&self) -> &str
pub fn source_url(&self) -> &str
Source url to be set for the script.
Sourcepub fn persist_script(&self) -> bool
pub fn persist_script(&self) -> bool
Specifies whether the compiled script should be persisted.
Sourcepub fn execution_context_id(&self) -> Option<&ExecutionContextId>
pub fn execution_context_id(&self) -> Option<&ExecutionContextId>
Specifies in which execution context to perform script run. If the parameter is omitted the evaluation will be performed in the context of the inspected page.