pub struct CompileScriptParamsBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> CompileScriptParamsBuilder<'a>
impl<'a> CompileScriptParamsBuilder<'a>
Sourcepub fn execution_context_id(
self,
execution_context_id: ExecutionContextId,
) -> Self
pub fn execution_context_id( self, execution_context_id: ExecutionContextId, ) -> Self
Specifies in which execution context to perform script run. If the parameter is omitted the evaluation will be performed in the context of the inspected page.
pub fn build(self) -> CompileScriptParams<'a>