CustomPreviewBuilder

Struct CustomPreviewBuilder 

pub struct CustomPreviewBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> CustomPreviewBuilder<'a>

pub fn body_getter_id( self, body_getter_id: impl Into<RemoteObjectId<'a>>, ) -> Self

If formatter returns true as a result of formatter.hasBody call then bodyGetterId will contain RemoteObjectId for the function that returns result of formatter.body(object, config) call. The result value is json ML array.

pub fn build(self) -> CustomPreview<'a>