pub struct DeepSerializedValue<'a> { /* private fields */ }Expand description
Represents deep serialized value.
Implementations
Sourceimpl<'a> DeepSerializedValue<'a>
impl<'a> DeepSerializedValue<'a>
Sourcepub fn builder(type_: impl Into<Cow<'a, str>>) -> DeepSerializedValueBuilder<'a>
pub fn builder(type_: impl Into<Cow<'a, str>>) -> DeepSerializedValueBuilder<'a>
Creates a builder for this type with the required parameters:
type_:
pub fn type_(&self) -> &str
pub fn value(&self) -> Option<&JsonValue>
pub fn object_id(&self) -> Option<&str>
Sourcepub fn weak_local_object_reference(&self) -> Option<i64>
pub fn weak_local_object_reference(&self) -> Option<i64>
Set if value reference met more then once during serialization. In such case, value is provided only to one of the serialized values. Unique per value in the scope of one CDP call.