DeepSerializedValueBuilder

Struct DeepSerializedValueBuilder 

pub struct DeepSerializedValueBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> DeepSerializedValueBuilder<'a>

pub fn value(self, value: JsonValue) -> Self

pub fn object_id(self, object_id: impl Into<Cow<'a, str>>) -> Self

pub fn weak_local_object_reference( self, weak_local_object_reference: i64, ) -> Self

Set if value reference met more then once during serialization. In such case, value is provided only to one of the serialized values. Unique per value in the scope of one CDP call.

pub fn build(self) -> DeepSerializedValue<'a>