pub struct EvaluateParams<'a> { /* private fields */ }Expand description
Evaluates expression on global object.
Implementations
Sourceimpl<'a> EvaluateParams<'a>
impl<'a> EvaluateParams<'a>
Sourcepub fn builder(expression: impl Into<Cow<'a, str>>) -> EvaluateParamsBuilder<'a>
pub fn builder(expression: impl Into<Cow<'a, str>>) -> EvaluateParamsBuilder<'a>
Creates a builder for this type with the required parameters:
expression: Expression to evaluate.
Sourcepub fn expression(&self) -> &str
pub fn expression(&self) -> &str
Expression to evaluate.
Sourcepub fn object_group(&self) -> Option<&str>
pub fn object_group(&self) -> Option<&str>
Symbolic group name that can be used to release multiple objects.
Sourcepub fn include_command_line_api(&self) -> Option<bool>
pub fn include_command_line_api(&self) -> Option<bool>
Determines whether Command Line API should be available during the evaluation.
Sourcepub fn silent(&self) -> Option<bool>
pub fn silent(&self) -> Option<bool>
In silent mode exceptions thrown during evaluation are not reported and do not pause execution. Overrides ‘setPauseOnException’ state.
Sourcepub fn context_id(&self) -> Option<&ExecutionContextId>
pub fn context_id(&self) -> Option<&ExecutionContextId>
Specifies in which execution context to perform evaluation. If the parameter is omitted the evaluation will be performed in the context of the inspected page. This is mutually exclusive with ‘uniqueContextId’, which offers an alternative way to identify the execution context that is more reliable in a multi-process environment.
Sourcepub fn return_by_value(&self) -> Option<bool>
pub fn return_by_value(&self) -> Option<bool>
Whether the result is expected to be a JSON object that should be sent by value.
Sourcepub fn generate_preview(&self) -> Option<bool>
pub fn generate_preview(&self) -> Option<bool>
Whether preview should be generated for the result.
Sourcepub fn user_gesture(&self) -> Option<bool>
pub fn user_gesture(&self) -> Option<bool>
Whether execution should be treated as initiated by user in the UI.
Sourcepub fn await_promise(&self) -> Option<bool>
pub fn await_promise(&self) -> Option<bool>
Whether execution should ‘await’ for resulting value and return once awaited promise is resolved.
Sourcepub fn throw_on_side_effect(&self) -> Option<bool>
pub fn throw_on_side_effect(&self) -> Option<bool>
Whether to throw an exception if side effect cannot be ruled out during evaluation. This implies ‘disableBreaks’ below.
Sourcepub fn timeout(&self) -> Option<&TimeDelta>
pub fn timeout(&self) -> Option<&TimeDelta>
Terminate execution after timing out (number of milliseconds).
Sourcepub fn disable_breaks(&self) -> Option<bool>
pub fn disable_breaks(&self) -> Option<bool>
Disable breakpoints during execution.
Sourcepub fn repl_mode(&self) -> Option<bool>
pub fn repl_mode(&self) -> Option<bool>
Setting this flag to true enables ‘let’ re-declaration and top-level ‘await’. Note that ‘let’ variables can only be re-declared if they originate from ‘replMode’ themselves.
Sourcepub fn allow_unsafe_eval_blocked_by_csp(&self) -> Option<bool>
pub fn allow_unsafe_eval_blocked_by_csp(&self) -> Option<bool>
The Content Security Policy (CSP) for the target might block ‘unsafe-eval’ which includes eval(), Function(), setTimeout() and setInterval() when called with non-callable arguments. This flag bypasses CSP for this evaluation and allows unsafe-eval. Defaults to true.
Sourcepub fn unique_context_id(&self) -> Option<&str>
pub fn unique_context_id(&self) -> Option<&str>
An alternative way to specify the execution context to evaluate in. Compared to contextId that may be reused across processes, this is guaranteed to be system-unique, so it can be used to prevent accidental evaluation of the expression in context different than intended (e.g. as a result of navigation across process boundaries). This is mutually exclusive with ‘contextId’.
Sourcepub fn serialization_options(&self) -> Option<&SerializationOptions<'a>>
pub fn serialization_options(&self) -> Option<&SerializationOptions<'a>>
Specifies the result serialization. If provided, overrides ‘generatePreview’ and ‘returnByValue’.