ExceptionDetailsBuilder

Struct ExceptionDetailsBuilder 

pub struct ExceptionDetailsBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> ExceptionDetailsBuilder<'a>

pub fn script_id(self, script_id: impl Into<ScriptId<'a>>) -> Self

Script ID of the exception location.

pub fn url(self, url: impl Into<Cow<'a, str>>) -> Self

URL of the exception location, to be used when the script was not reported.

pub fn stack_trace(self, stack_trace: StackTrace<'a>) -> Self

JavaScript stack trace if available.

pub fn exception(self, exception: RemoteObject<'a>) -> Self

Exception object if available.

pub fn execution_context_id( self, execution_context_id: ExecutionContextId, ) -> Self

Identifier of the context where exception happened.

pub fn exception_meta_data( self, exception_meta_data: Map<String, JsonValue>, ) -> Self

Dictionary with entries of meta data that the client associated with this exception, such as information about associated network requests, etc.

pub fn build(self) -> ExceptionDetails<'a>