GetExceptionDetailsParams

Struct GetExceptionDetailsParams 

pub struct GetExceptionDetailsParams<'a> { /* private fields */ }
This method tries to lookup and populate exception details for a JavaScript Error object. Note that the stackTrace portion of the resulting exceptionDetails will only be populated if the Runtime domain was enabled at the time when the Error was thrown.

Implementations

Source

impl<'a> GetExceptionDetailsParams<'a>

pub fn builder( error_object_id: impl Into<RemoteObjectId<'a>>, ) -> GetExceptionDetailsParamsBuilder<'a>

Creates a builder for this type with the required parameters:

  • error_object_id: The error object for which to resolve the exception details.
pub fn error_object_id(&self) -> &RemoteObjectId<'a>

The error object for which to resolve the exception details.

Source

impl<'a> GetExceptionDetailsParams<'a>

pub const METHOD: &'static str = "Runtime.getExceptionDetails"