pub struct GetHeapUsageReturns { /* private fields */ }Expand description
Returns the JavaScript heap usage. It is the total usage of the corresponding isolate not scoped to a particular Runtime.
Implementations
Sourceimpl GetHeapUsageReturns
impl GetHeapUsageReturns
Sourcepub fn builder(
used_size: f64,
total_size: f64,
embedder_heap_used_size: f64,
backing_storage_size: f64,
) -> GetHeapUsageReturnsBuilder
pub fn builder( used_size: f64, total_size: f64, embedder_heap_used_size: f64, backing_storage_size: f64, ) -> GetHeapUsageReturnsBuilder
Creates a builder for this type with the required parameters:
used_size: Used JavaScript heap size in bytes.total_size: Allocated JavaScript heap size in bytes.embedder_heap_used_size: Used size in bytes in the embedder’s garbage-collected heap.backing_storage_size: Size in bytes of backing storage for array buffers and external strings.
Sourcepub fn total_size(&self) -> f64
pub fn total_size(&self) -> f64
Allocated JavaScript heap size in bytes.
Sourcepub fn embedder_heap_used_size(&self) -> f64
pub fn embedder_heap_used_size(&self) -> f64
Used size in bytes in the embedder’s garbage-collected heap.
Sourcepub fn backing_storage_size(&self) -> f64
pub fn backing_storage_size(&self) -> f64
Size in bytes of backing storage for array buffers and external strings.