pub struct GetPropertiesReturns<'a> { /* private fields */ }Expand description
Returns properties of a given object. Object group of the result is inherited from the target object.
Implementations
Sourceimpl<'a> GetPropertiesReturns<'a>
impl<'a> GetPropertiesReturns<'a>
Sourcepub fn builder(
result: Vec<PropertyDescriptor<'a>>,
) -> GetPropertiesReturnsBuilder<'a>
pub fn builder( result: Vec<PropertyDescriptor<'a>>, ) -> GetPropertiesReturnsBuilder<'a>
Creates a builder for this type with the required parameters:
result: Object properties.
Sourcepub fn result(&self) -> &[PropertyDescriptor<'a>]
pub fn result(&self) -> &[PropertyDescriptor<'a>]
Object properties.
Sourcepub fn internal_properties(&self) -> Option<&[InternalPropertyDescriptor<'a>]>
pub fn internal_properties(&self) -> Option<&[InternalPropertyDescriptor<'a>]>
Internal object properties (only of the element itself).
Sourcepub fn private_properties(&self) -> Option<&[PrivatePropertyDescriptor<'a>]>
pub fn private_properties(&self) -> Option<&[PrivatePropertyDescriptor<'a>]>
Object private properties.
Sourcepub fn exception_details(&self) -> Option<&ExceptionDetails<'a>>
pub fn exception_details(&self) -> Option<&ExceptionDetails<'a>>
Exception details.