pub struct ObjectPreview<'a> { /* private fields */ }Expand description
Object containing abbreviated remote object value.
Implementations
Sourceimpl<'a> ObjectPreview<'a>
impl<'a> ObjectPreview<'a>
Sourcepub fn builder(
type_: impl Into<Cow<'a, str>>,
overflow: bool,
properties: Vec<PropertyPreview<'a>>,
) -> ObjectPreviewBuilder<'a>
pub fn builder( type_: impl Into<Cow<'a, str>>, overflow: bool, properties: Vec<PropertyPreview<'a>>, ) -> ObjectPreviewBuilder<'a>
Creates a builder for this type with the required parameters:
type_: Object type.overflow: True iff some of the properties or entries of the original object did not fit.properties: List of the properties.
Sourcepub fn subtype(&self) -> Option<&str>
pub fn subtype(&self) -> Option<&str>
Object subtype hint. Specified for ‘object’ type values only.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
String representation of the object.
Sourcepub fn overflow(&self) -> bool
pub fn overflow(&self) -> bool
True iff some of the properties or entries of the original object did not fit.
Sourcepub fn properties(&self) -> &[PropertyPreview<'a>]
pub fn properties(&self) -> &[PropertyPreview<'a>]
List of the properties.
Sourcepub fn entries(&self) -> Option<&[EntryPreview<'a>]>
pub fn entries(&self) -> Option<&[EntryPreview<'a>]>
List of the entries. Specified for ‘map’ and ‘set’ subtype values only.