pub struct PrivatePropertyDescriptorBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> PrivatePropertyDescriptorBuilder<'a>
impl<'a> PrivatePropertyDescriptorBuilder<'a>
Sourcepub fn value(self, value: RemoteObject<'a>) -> Self
pub fn value(self, value: RemoteObject<'a>) -> Self
The value associated with the private property.
Sourcepub fn get(self, get: RemoteObject<'a>) -> Self
pub fn get(self, get: RemoteObject<'a>) -> Self
A function which serves as a getter for the private property, or ‘undefined’ if there is no getter (accessor descriptors only).
Sourcepub fn set(self, set: RemoteObject<'a>) -> Self
pub fn set(self, set: RemoteObject<'a>) -> Self
A function which serves as a setter for the private property, or ‘undefined’ if there is no setter (accessor descriptors only).
pub fn build(self) -> PrivatePropertyDescriptor<'a>