pub struct PropertyDescriptorBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> PropertyDescriptorBuilder<'a>
impl<'a> PropertyDescriptorBuilder<'a>
Sourcepub fn value(self, value: RemoteObject<'a>) -> Self
pub fn value(self, value: RemoteObject<'a>) -> Self
The value associated with the property.
Sourcepub fn writable(self, writable: bool) -> Self
pub fn writable(self, writable: bool) -> Self
True if the value associated with the property may be changed (data descriptors only).
Sourcepub fn get(self, get: RemoteObject<'a>) -> Self
pub fn get(self, get: RemoteObject<'a>) -> Self
A function which serves as a getter for the property, or ‘undefined’ if there is no getter (accessor descriptors only).
Sourcepub fn set(self, set: RemoteObject<'a>) -> Self
pub fn set(self, set: RemoteObject<'a>) -> Self
A function which serves as a setter for the property, or ‘undefined’ if there is no setter (accessor descriptors only).
Sourcepub fn was_thrown(self, was_thrown: bool) -> Self
pub fn was_thrown(self, was_thrown: bool) -> Self
True if the result was thrown during the evaluation.
Sourcepub fn symbol(self, symbol: RemoteObject<'a>) -> Self
pub fn symbol(self, symbol: RemoteObject<'a>) -> Self
Property symbol object, if the property is of the ‘symbol’ type.
pub fn build(self) -> PropertyDescriptor<'a>