pub struct PropertyPreview<'a> { /* private fields */ }Implementations
Sourceimpl<'a> PropertyPreview<'a>
impl<'a> PropertyPreview<'a>
Sourcepub fn builder(
name: impl Into<Cow<'a, str>>,
type_: impl Into<Cow<'a, str>>,
) -> PropertyPreviewBuilder<'a>
pub fn builder( name: impl Into<Cow<'a, str>>, type_: impl Into<Cow<'a, str>>, ) -> PropertyPreviewBuilder<'a>
Creates a builder for this type with the required parameters:
name: Property name.type_: Object type. Accessor means that the property itself is an accessor property.
Sourcepub fn type_(&self) -> &str
pub fn type_(&self) -> &str
Object type. Accessor means that the property itself is an accessor property.
Sourcepub fn value_preview(&self) -> Option<&ObjectPreview<'a>>
pub fn value_preview(&self) -> Option<&ObjectPreview<'a>>
Nested value preview.