pub struct QueryObjectsParams<'a> { /* private fields */ }Implementations
Sourceimpl<'a> QueryObjectsParams<'a>
impl<'a> QueryObjectsParams<'a>
Sourcepub fn builder(
prototype_object_id: impl Into<RemoteObjectId<'a>>,
) -> QueryObjectsParamsBuilder<'a>
pub fn builder( prototype_object_id: impl Into<RemoteObjectId<'a>>, ) -> QueryObjectsParamsBuilder<'a>
Creates a builder for this type with the required parameters:
prototype_object_id: Identifier of the prototype to return objects for.
Sourcepub fn prototype_object_id(&self) -> &RemoteObjectId<'a>
pub fn prototype_object_id(&self) -> &RemoteObjectId<'a>
Identifier of the prototype to return objects for.
Sourcepub fn object_group(&self) -> Option<&str>
pub fn object_group(&self) -> Option<&str>
Symbolic group name that can be used to release the results.