pub struct RemoteObject<'a> { /* private fields */ }Expand description
Mirror object referencing original JavaScript object.
Implementations
Sourceimpl<'a> RemoteObject<'a>
impl<'a> RemoteObject<'a>
Sourcepub fn builder(type_: impl Into<Cow<'a, str>>) -> RemoteObjectBuilder<'a>
pub fn builder(type_: impl Into<Cow<'a, str>>) -> RemoteObjectBuilder<'a>
Creates a builder for this type with the required parameters:
type_: Object type.
Sourcepub fn subtype(&self) -> Option<&str>
pub fn subtype(&self) -> Option<&str>
Object subtype hint. Specified for ‘object’ type values only. NOTE: If you change anything here, make sure to also update ‘subtype’ in ‘ObjectPreview’ and ‘PropertyPreview’ below.
Sourcepub fn class_name(&self) -> Option<&str>
pub fn class_name(&self) -> Option<&str>
Object class (constructor) name. Specified for ‘object’ type values only.
Sourcepub fn value(&self) -> Option<&JsonValue>
pub fn value(&self) -> Option<&JsonValue>
Remote object value in case of primitive values or JSON values (if it was requested).
Sourcepub fn unserializable_value(&self) -> Option<&UnserializableValue<'a>>
pub fn unserializable_value(&self) -> Option<&UnserializableValue<'a>>
Primitive value which can not be JSON-stringified does not have ‘value’, but gets this property.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
String representation of the object.
Sourcepub fn deep_serialized_value(&self) -> Option<&DeepSerializedValue<'a>>
pub fn deep_serialized_value(&self) -> Option<&DeepSerializedValue<'a>>
Deep serialized value.
Sourcepub fn object_id(&self) -> Option<&RemoteObjectId<'a>>
pub fn object_id(&self) -> Option<&RemoteObjectId<'a>>
Unique object identifier (for non-primitive values).
Sourcepub fn preview(&self) -> Option<&ObjectPreview<'a>>
pub fn preview(&self) -> Option<&ObjectPreview<'a>>
Preview containing abbreviated property values. Specified for ‘object’ type values only.
pub fn custom_preview(&self) -> Option<&CustomPreview<'a>>