pub struct RemoteObjectBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> RemoteObjectBuilder<'a>
impl<'a> RemoteObjectBuilder<'a>
Sourcepub fn subtype(self, subtype: impl Into<Cow<'a, str>>) -> Self
pub fn subtype(self, subtype: impl Into<Cow<'a, str>>) -> Self
Object subtype hint. Specified for ‘object’ type values only. NOTE: If you change anything here, make sure to also update ‘subtype’ in ‘ObjectPreview’ and ‘PropertyPreview’ below.
Sourcepub fn class_name(self, class_name: impl Into<Cow<'a, str>>) -> Self
pub fn class_name(self, class_name: impl Into<Cow<'a, str>>) -> Self
Object class (constructor) name. Specified for ‘object’ type values only.
Sourcepub fn value(self, value: JsonValue) -> Self
pub fn value(self, value: JsonValue) -> Self
Remote object value in case of primitive values or JSON values (if it was requested).
Sourcepub fn unserializable_value(
self,
unserializable_value: impl Into<UnserializableValue<'a>>,
) -> Self
pub fn unserializable_value( self, unserializable_value: impl Into<UnserializableValue<'a>>, ) -> Self
Primitive value which can not be JSON-stringified does not have ‘value’, but gets this property.
Sourcepub fn description(self, description: impl Into<Cow<'a, str>>) -> Self
pub fn description(self, description: impl Into<Cow<'a, str>>) -> Self
String representation of the object.
Sourcepub fn deep_serialized_value(
self,
deep_serialized_value: DeepSerializedValue<'a>,
) -> Self
pub fn deep_serialized_value( self, deep_serialized_value: DeepSerializedValue<'a>, ) -> Self
Deep serialized value.
Sourcepub fn object_id(self, object_id: impl Into<RemoteObjectId<'a>>) -> Self
pub fn object_id(self, object_id: impl Into<RemoteObjectId<'a>>) -> Self
Unique object identifier (for non-primitive values).
Sourcepub fn preview(self, preview: ObjectPreview<'a>) -> Self
pub fn preview(self, preview: ObjectPreview<'a>) -> Self
Preview containing abbreviated property values. Specified for ‘object’ type values only.
pub fn custom_preview(self, custom_preview: CustomPreview<'a>) -> Self
pub fn build(self) -> RemoteObject<'a>