pub struct RemoveBindingParams {
pub name: String,
}Expand description
This method does not remove binding function from global object but unsubscribes current runtime agent from Runtime.bindingCalled notifications.
Fields
name: StringTrait Implementations
Sourceimpl Clone for RemoveBindingParams
impl Clone for RemoveBindingParams
Sourcefn clone(&self) -> RemoveBindingParams
fn clone(&self) -> RemoveBindingParams
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RemoveBindingParams
impl Debug for RemoveBindingParams
Sourceimpl Default for RemoveBindingParams
impl Default for RemoveBindingParams
Sourcefn default() -> RemoveBindingParams
fn default() -> RemoveBindingParams
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for RemoveBindingParams
impl<'de> Deserialize<'de> for RemoveBindingParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more