pub struct RunScriptParams<'a> { /* private fields */ }Expand description
Runs script with given id in a given context.
Implementations
Sourceimpl<'a> RunScriptParams<'a>
impl<'a> RunScriptParams<'a>
Sourcepub fn builder(script_id: impl Into<ScriptId<'a>>) -> RunScriptParamsBuilder<'a>
pub fn builder(script_id: impl Into<ScriptId<'a>>) -> RunScriptParamsBuilder<'a>
Creates a builder for this type with the required parameters:
script_id: Id of the script to run.
Sourcepub fn execution_context_id(&self) -> Option<&ExecutionContextId>
pub fn execution_context_id(&self) -> Option<&ExecutionContextId>
Specifies in which execution context to perform script run. If the parameter is omitted the evaluation will be performed in the context of the inspected page.
Sourcepub fn object_group(&self) -> Option<&str>
pub fn object_group(&self) -> Option<&str>
Symbolic group name that can be used to release multiple objects.
Sourcepub fn silent(&self) -> Option<bool>
pub fn silent(&self) -> Option<bool>
In silent mode exceptions thrown during evaluation are not reported and do not pause execution. Overrides ‘setPauseOnException’ state.
Sourcepub fn include_command_line_api(&self) -> Option<bool>
pub fn include_command_line_api(&self) -> Option<bool>
Determines whether Command Line API should be available during the evaluation.
Sourcepub fn return_by_value(&self) -> Option<bool>
pub fn return_by_value(&self) -> Option<bool>
Whether the result is expected to be a JSON object which should be sent by value.
Sourcepub fn generate_preview(&self) -> Option<bool>
pub fn generate_preview(&self) -> Option<bool>
Whether preview should be generated for the result.
Sourcepub fn await_promise(&self) -> Option<bool>
pub fn await_promise(&self) -> Option<bool>
Whether execution should ‘await’ for resulting value and return once awaited promise is resolved.