pub struct RunScriptParamsBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> RunScriptParamsBuilder<'a>
impl<'a> RunScriptParamsBuilder<'a>
Sourcepub fn execution_context_id(
self,
execution_context_id: ExecutionContextId,
) -> Self
pub fn execution_context_id( self, execution_context_id: ExecutionContextId, ) -> Self
Specifies in which execution context to perform script run. If the parameter is omitted the evaluation will be performed in the context of the inspected page.
Sourcepub fn object_group(self, object_group: impl Into<Cow<'a, str>>) -> Self
pub fn object_group(self, object_group: impl Into<Cow<'a, str>>) -> Self
Symbolic group name that can be used to release multiple objects.
Sourcepub fn silent(self, silent: bool) -> Self
pub fn silent(self, silent: bool) -> Self
In silent mode exceptions thrown during evaluation are not reported and do not pause execution. Overrides ‘setPauseOnException’ state.
Sourcepub fn include_command_line_api(self, include_command_line_api: bool) -> Self
pub fn include_command_line_api(self, include_command_line_api: bool) -> Self
Determines whether Command Line API should be available during the evaluation.
Sourcepub fn return_by_value(self, return_by_value: bool) -> Self
pub fn return_by_value(self, return_by_value: bool) -> Self
Whether the result is expected to be a JSON object which should be sent by value.
Sourcepub fn generate_preview(self, generate_preview: bool) -> Self
pub fn generate_preview(self, generate_preview: bool) -> Self
Whether preview should be generated for the result.
Sourcepub fn await_promise(self, await_promise: bool) -> Self
pub fn await_promise(self, await_promise: bool) -> Self
Whether execution should ‘await’ for resulting value and return once awaited promise is resolved.
pub fn build(self) -> RunScriptParams<'a>