pub struct StackTrace<'a> { /* private fields */ }Expand description
Call frames for assertions or error messages.
Implementations
Sourceimpl<'a> StackTrace<'a>
impl<'a> StackTrace<'a>
Sourcepub fn builder(call_frames: Vec<CallFrame<'a>>) -> StackTraceBuilder<'a>
pub fn builder(call_frames: Vec<CallFrame<'a>>) -> StackTraceBuilder<'a>
Creates a builder for this type with the required parameters:
call_frames: JavaScript function name.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
String label of this stack trace. For async traces this may be a name of the function that initiated the async call.
Sourcepub fn call_frames(&self) -> &[CallFrame<'a>]
pub fn call_frames(&self) -> &[CallFrame<'a>]
JavaScript function name.
Sourcepub fn parent(&self) -> Option<&StackTrace<'a>>
pub fn parent(&self) -> Option<&StackTrace<'a>>
Asynchronous JavaScript stack trace that preceded this stack, if available.
Sourcepub fn parent_id(&self) -> Option<&StackTraceId<'a>>
pub fn parent_id(&self) -> Option<&StackTraceId<'a>>
Asynchronous JavaScript stack trace that preceded this stack, if available.