StackTraceBuilder

Struct StackTraceBuilder 

pub struct StackTraceBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> StackTraceBuilder<'a>

pub fn description(self, description: impl Into<Cow<'a, str>>) -> Self

String label of this stack trace. For async traces this may be a name of the function that initiated the async call.

pub fn parent(self, parent: Box<StackTrace<'a>>) -> Self

Asynchronous JavaScript stack trace that preceded this stack, if available.

pub fn parent_id(self, parent_id: StackTraceId<'a>) -> Self

Asynchronous JavaScript stack trace that preceded this stack, if available.

pub fn build(self) -> StackTrace<'a>