pub struct StackTraceId<'a> { /* private fields */ }Expand description
If ‘debuggerId’ is set stack trace comes from another debugger and can be resolved there. This allows to track cross-debugger calls. See ‘Runtime.StackTrace’ and ‘Debugger.paused’ for usages.
Implementations
Sourceimpl<'a> StackTraceId<'a>
impl<'a> StackTraceId<'a>
Sourcepub fn builder(id: impl Into<Cow<'a, str>>) -> StackTraceIdBuilder<'a>
pub fn builder(id: impl Into<Cow<'a, str>>) -> StackTraceIdBuilder<'a>
Creates a builder for this type with the required parameters:
id:
pub fn id(&self) -> &str
pub fn debugger_id(&self) -> Option<&UniqueDebuggerId<'a>>