Debugger domain exposes JavaScript debugging capabilities. It allows setting and removing breakpoints, stepping through execution, exploring stack traces, etc.
Structs
- Break
Location - Break
Location Builder - Call
Frame - JavaScript call frame. Array of call frames form the call stack.
- Call
Frame Builder - Continue
ToLocation Params - Continues execution until specific location is reached.
- Continue
ToLocation Params Builder - Debug
Symbols - Debug symbols available for a wasm script.
- Debug
Symbols Builder - Disable
Params - Disassemble
Wasm Module Params - Disassemble
Wasm Module Params Builder - Disassemble
Wasm Module Returns - Disassemble
Wasm Module Returns Builder - Enable
Params - Enables debugger for the given page. Clients should not assume that the debugging has been enabled until the result for this command is received.
- Enable
Params Builder - Enable
Returns - Enables debugger for the given page. Clients should not assume that the debugging has been enabled until the result for this command is received.
- Enable
Returns Builder - Evaluate
OnCall Frame Params - Evaluates expression on a given call frame.
- Evaluate
OnCall Frame Params Builder - Evaluate
OnCall Frame Returns - Evaluates expression on a given call frame.
- Evaluate
OnCall Frame Returns Builder - GetPossible
Breakpoints Params - Returns possible locations for breakpoint. scriptId in start and end range locations should be the same.
- GetPossible
Breakpoints Params Builder - GetPossible
Breakpoints Returns - Returns possible locations for breakpoint. scriptId in start and end range locations should be the same.
- GetPossible
Breakpoints Returns Builder - GetScript
Source Params - Returns source for the script with given id.
- GetScript
Source Params Builder - GetScript
Source Returns - Returns source for the script with given id.
- GetScript
Source Returns Builder - GetStack
Trace Params - Returns stack trace with given ‘stackTraceId’.
- GetStack
Trace Params Builder - GetStack
Trace Returns - Returns stack trace with given ‘stackTraceId’.
- GetStack
Trace Returns Builder - GetWasm
Bytecode Params - This command is deprecated. Use getScriptSource instead.
- GetWasm
Bytecode Params Builder - GetWasm
Bytecode Returns - This command is deprecated. Use getScriptSource instead.
- GetWasm
Bytecode Returns Builder - Location
- Location in the source code.
- Location
Builder - Location
Range - Location range within one script.
- Location
Range Builder - Next
Wasm Disassembly Chunk Params - Disassemble the next chunk of lines for the module corresponding to the stream. If disassembly is complete, this API will invalidate the streamId and return an empty chunk. Any subsequent calls for the now invalid stream will return errors.
- Next
Wasm Disassembly Chunk Params Builder - Next
Wasm Disassembly Chunk Returns - Disassemble the next chunk of lines for the module corresponding to the stream. If disassembly is complete, this API will invalidate the streamId and return an empty chunk. Any subsequent calls for the now invalid stream will return errors.
- Next
Wasm Disassembly Chunk Returns Builder - Pause
OnAsync Call Params - Pause
OnAsync Call Params Builder - Pause
Params - Remove
Breakpoint Params - Removes JavaScript breakpoint.
- Remove
Breakpoint Params Builder - Resolved
Breakpoint - Resolved
Breakpoint Builder - Restart
Frame Params - Restarts particular call frame from the beginning. The old, deprecated behavior of ‘restartFrame’ is to stay paused and allow further CDP commands after a restart was scheduled. This can cause problems with restarting, so we now continue execution immediatly after it has been scheduled until we reach the beginning of the restarted frame.
- Restart
Frame Params Builder - Restart
Frame Returns - Restarts particular call frame from the beginning. The old, deprecated behavior of ‘restartFrame’ is to stay paused and allow further CDP commands after a restart was scheduled. This can cause problems with restarting, so we now continue execution immediatly after it has been scheduled until we reach the beginning of the restarted frame.
- Restart
Frame Returns Builder - Resume
Params - Resumes JavaScript execution.
- Resume
Params Builder - Scope
- Scope description.
- Scope
Builder - Script
Position - Location in the source code.
- Script
Position Builder - Search
InContent Params - Searches for given string in script content.
- Search
InContent Params Builder - Search
InContent Returns - Searches for given string in script content.
- Search
InContent Returns Builder - Search
Match - Search match for resource.
- Search
Match Builder - SetAsync
Call Stack Depth Params - Enables or disables async call stacks tracking.
- SetAsync
Call Stack Depth Params Builder - SetBlackbox
Execution Contexts Params - Replace previous blackbox execution contexts with passed ones. Forces backend to skip stepping/pausing in scripts in these execution contexts. VM will try to leave blackboxed script by performing ‘step in’ several times, finally resorting to ‘step out’ if unsuccessful.
- SetBlackbox
Execution Contexts Params Builder - SetBlackbox
Patterns Params - Replace previous blackbox patterns with passed ones. Forces backend to skip stepping/pausing in scripts with url matching one of the patterns. VM will try to leave blackboxed script by performing ‘step in’ several times, finally resorting to ‘step out’ if unsuccessful.
- SetBlackbox
Patterns Params Builder - SetBlackboxed
Ranges Params - Makes backend skip steps in the script in blackboxed ranges. VM will try leave blacklisted scripts by performing ‘step in’ several times, finally resorting to ‘step out’ if unsuccessful. Positions array contains positions where blackbox state is changed. First interval isn’t blackboxed. Array should be sorted.
- SetBlackboxed
Ranges Params Builder - SetBreakpoint
ByUrl Params - Sets JavaScript breakpoint at given location specified either by URL or URL regex. Once this command is issued, all existing parsed scripts will have breakpoints resolved and returned in ‘locations’ property. Further matching script parsing will result in subsequent ‘breakpointResolved’ events issued. This logical breakpoint will survive page reloads.
- SetBreakpoint
ByUrl Params Builder - SetBreakpoint
ByUrl Returns - Sets JavaScript breakpoint at given location specified either by URL or URL regex. Once this command is issued, all existing parsed scripts will have breakpoints resolved and returned in ‘locations’ property. Further matching script parsing will result in subsequent ‘breakpointResolved’ events issued. This logical breakpoint will survive page reloads.
- SetBreakpoint
ByUrl Returns Builder - SetBreakpoint
OnFunction Call Params - Sets JavaScript breakpoint before each call to the given function. If another function was created from the same source as a given one, calling it will also trigger the breakpoint.
- SetBreakpoint
OnFunction Call Params Builder - SetBreakpoint
OnFunction Call Returns - Sets JavaScript breakpoint before each call to the given function. If another function was created from the same source as a given one, calling it will also trigger the breakpoint.
- SetBreakpoint
OnFunction Call Returns Builder - SetBreakpoint
Params - Sets JavaScript breakpoint at a given location.
- SetBreakpoint
Params Builder - SetBreakpoint
Returns - Sets JavaScript breakpoint at a given location.
- SetBreakpoint
Returns Builder - SetBreakpoints
Active Params - Activates / deactivates all breakpoints on the page.
- SetBreakpoints
Active Params Builder - SetInstrumentation
Breakpoint Params - Sets instrumentation breakpoint.
- SetInstrumentation
Breakpoint Params Builder - SetInstrumentation
Breakpoint Returns - Sets instrumentation breakpoint.
- SetInstrumentation
Breakpoint Returns Builder - SetPause
OnExceptions Params - Defines pause on exceptions state. Can be set to stop on all exceptions, uncaught exceptions, or caught exceptions, no exceptions. Initial pause on exceptions state is ‘none’.
- SetPause
OnExceptions Params Builder - SetReturn
Value Params - Changes return value in top frame. Available only at return break position.
- SetReturn
Value Params Builder - SetScript
Source Params - Edits JavaScript source live.
- SetScript
Source Params Builder - SetScript
Source Returns - Edits JavaScript source live.
- SetScript
Source Returns Builder - SetSkip
AllPauses Params - Makes page not interrupt on any pauses (breakpoint, exception, dom exception etc).
- SetSkip
AllPauses Params Builder - SetVariable
Value Params - Changes value of variable in a callframe. Object-based scopes are not supported and must be mutated manually.
- SetVariable
Value Params Builder - Step
Into Params - Steps into the function call.
- Step
Into Params Builder - Step
OutParams - Step
Over Params - Steps over the statement.
- Step
Over Params Builder - Wasm
Disassembly Chunk - Wasm
Disassembly Chunk Builder
Enums
- Script
Language - Enum of possible script languages.
Type Aliases
- Breakpoint
Id - Breakpoint identifier.
- Call
Frame Id - Call frame identifier.