Module debugger

Module debugger 

Debugger domain exposes JavaScript debugging capabilities. It allows setting and removing breakpoints, stepping through execution, exploring stack traces, etc.

Structs

BreakLocation
CallFrame
JavaScript call frame. Array of call frames form the call stack.
ContinueToLocationParams
Continues execution until specific location is reached.
DebugSymbols
Debug symbols available for a wasm script.
DisableParams
DisassembleWasmModuleParams
DisassembleWasmModuleReturns
EnableParams
Enables debugger for the given page. Clients should not assume that the debugging has been enabled until the result for this command is received.
EnableReturns
Enables debugger for the given page. Clients should not assume that the debugging has been enabled until the result for this command is received.
EvaluateOnCallFrameParams
Evaluates expression on a given call frame.
EvaluateOnCallFrameReturns
Evaluates expression on a given call frame.
GetPossibleBreakpointsParams
Returns possible locations for breakpoint. scriptId in start and end range locations should be the same.
GetPossibleBreakpointsReturns
Returns possible locations for breakpoint. scriptId in start and end range locations should be the same.
GetScriptSourceParams
Returns source for the script with given id.
GetScriptSourceReturns
Returns source for the script with given id.
GetStackTraceParams
Returns stack trace with given ‘stackTraceId’.
GetStackTraceReturns
Returns stack trace with given ‘stackTraceId’.
GetWasmBytecodeParams
This command is deprecated. Use getScriptSource instead.
GetWasmBytecodeReturns
This command is deprecated. Use getScriptSource instead.
Location
Location in the source code.
LocationRange
Location range within one script.
NextWasmDisassemblyChunkParams
Disassemble the next chunk of lines for the module corresponding to the stream. If disassembly is complete, this API will invalidate the streamId and return an empty chunk. Any subsequent calls for the now invalid stream will return errors.
NextWasmDisassemblyChunkReturns
Disassemble the next chunk of lines for the module corresponding to the stream. If disassembly is complete, this API will invalidate the streamId and return an empty chunk. Any subsequent calls for the now invalid stream will return errors.
PauseOnAsyncCallParams
PauseParams
RemoveBreakpointParams
Removes JavaScript breakpoint.
ResolvedBreakpoint
RestartFrameParams
Restarts particular call frame from the beginning. The old, deprecated behavior of ‘restartFrame’ is to stay paused and allow further CDP commands after a restart was scheduled. This can cause problems with restarting, so we now continue execution immediatly after it has been scheduled until we reach the beginning of the restarted frame.
RestartFrameReturns
Restarts particular call frame from the beginning. The old, deprecated behavior of ‘restartFrame’ is to stay paused and allow further CDP commands after a restart was scheduled. This can cause problems with restarting, so we now continue execution immediatly after it has been scheduled until we reach the beginning of the restarted frame.
ResumeParams
Resumes JavaScript execution.
Scope
Scope description.
ScriptPosition
Location in the source code.
SearchInContentParams
Searches for given string in script content.
SearchInContentReturns
Searches for given string in script content.
SearchMatch
Search match for resource.
SetAsyncCallStackDepthParams
Enables or disables async call stacks tracking.
SetBlackboxExecutionContextsParams
Replace previous blackbox execution contexts with passed ones. Forces backend to skip stepping/pausing in scripts in these execution contexts. VM will try to leave blackboxed script by performing ‘step in’ several times, finally resorting to ‘step out’ if unsuccessful.
SetBlackboxPatternsParams
Replace previous blackbox patterns with passed ones. Forces backend to skip stepping/pausing in scripts with url matching one of the patterns. VM will try to leave blackboxed script by performing ‘step in’ several times, finally resorting to ‘step out’ if unsuccessful.
SetBlackboxedRangesParams
Makes backend skip steps in the script in blackboxed ranges. VM will try leave blacklisted scripts by performing ‘step in’ several times, finally resorting to ‘step out’ if unsuccessful. Positions array contains positions where blackbox state is changed. First interval isn’t blackboxed. Array should be sorted.
SetBreakpointByUrlParams
Sets JavaScript breakpoint at given location specified either by URL or URL regex. Once this command is issued, all existing parsed scripts will have breakpoints resolved and returned in ‘locations’ property. Further matching script parsing will result in subsequent ‘breakpointResolved’ events issued. This logical breakpoint will survive page reloads.
SetBreakpointByUrlReturns
Sets JavaScript breakpoint at given location specified either by URL or URL regex. Once this command is issued, all existing parsed scripts will have breakpoints resolved and returned in ‘locations’ property. Further matching script parsing will result in subsequent ‘breakpointResolved’ events issued. This logical breakpoint will survive page reloads.
SetBreakpointOnFunctionCallParams
Sets JavaScript breakpoint before each call to the given function. If another function was created from the same source as a given one, calling it will also trigger the breakpoint.
SetBreakpointOnFunctionCallReturns
Sets JavaScript breakpoint before each call to the given function. If another function was created from the same source as a given one, calling it will also trigger the breakpoint.
SetBreakpointParams
Sets JavaScript breakpoint at a given location.
SetBreakpointReturns
Sets JavaScript breakpoint at a given location.
SetBreakpointsActiveParams
Activates / deactivates all breakpoints on the page.
SetInstrumentationBreakpointParams
Sets instrumentation breakpoint.
SetInstrumentationBreakpointReturns
Sets instrumentation breakpoint.
SetPauseOnExceptionsParams
Defines pause on exceptions state. Can be set to stop on all exceptions, uncaught exceptions, or caught exceptions, no exceptions. Initial pause on exceptions state is ‘none’.
SetReturnValueParams
Changes return value in top frame. Available only at return break position.
SetScriptSourceParams
Edits JavaScript source live.
SetScriptSourceReturns
Edits JavaScript source live.
SetSkipAllPausesParams
Makes page not interrupt on any pauses (breakpoint, exception, dom exception etc).
SetVariableValueParams
Changes value of variable in a callframe. Object-based scopes are not supported and must be mutated manually.
StepIntoParams
Steps into the function call.
StepOutParams
StepOverParams
Steps over the statement.
WasmDisassemblyChunk

Enums

ScriptLanguage
Enum of possible script languages.

Type Aliases

BreakpointId
Breakpoint identifier.
CallFrameId
Call frame identifier.