Debugger domain exposes JavaScript debugging capabilities. It allows setting and removing breakpoints, stepping through execution, exploring stack traces, etc.
Structs
- Break
Location - Call
Frame - JavaScript call frame. Array of call frames form the call stack.
- Continue
ToLocation Params - Continues execution until specific location is reached.
- Debug
Symbols - Debug symbols available for a wasm script.
- Disable
Params - Disassemble
Wasm Module Params - Disassemble
Wasm Module Returns - Enable
Params - Enables debugger for the given page. Clients should not assume that the debugging has been enabled until the result for this command is received.
- Enable
Returns - Enables debugger for the given page. Clients should not assume that the debugging has been enabled until the result for this command is received.
- Evaluate
OnCall Frame Params - Evaluates expression on a given call frame.
- Evaluate
OnCall Frame Returns - Evaluates expression on a given call frame.
- GetPossible
Breakpoints Params - Returns possible locations for breakpoint. scriptId in start and end range locations should be the same.
- GetPossible
Breakpoints Returns - Returns possible locations for breakpoint. scriptId in start and end range locations should be the same.
- GetScript
Source Params - Returns source for the script with given id.
- GetScript
Source Returns - Returns source for the script with given id.
- GetStack
Trace Params - Returns stack trace with given ‘stackTraceId’.
- GetStack
Trace Returns - Returns stack trace with given ‘stackTraceId’.
- GetWasm
Bytecode Params - This command is deprecated. Use getScriptSource instead.
- GetWasm
Bytecode Returns - This command is deprecated. Use getScriptSource instead.
- Location
- Location in the source code.
- Location
Range - Location range within one script.
- Next
Wasm Disassembly Chunk Params - Disassemble the next chunk of lines for the module corresponding to the stream. If disassembly is complete, this API will invalidate the streamId and return an empty chunk. Any subsequent calls for the now invalid stream will return errors.
- Next
Wasm Disassembly Chunk Returns - Disassemble the next chunk of lines for the module corresponding to the stream. If disassembly is complete, this API will invalidate the streamId and return an empty chunk. Any subsequent calls for the now invalid stream will return errors.
- Pause
OnAsync Call Params - Pause
Params - Remove
Breakpoint Params - Removes JavaScript breakpoint.
- Resolved
Breakpoint - Restart
Frame Params - Restarts particular call frame from the beginning. The old, deprecated behavior of ‘restartFrame’ is to stay paused and allow further CDP commands after a restart was scheduled. This can cause problems with restarting, so we now continue execution immediatly after it has been scheduled until we reach the beginning of the restarted frame.
- Restart
Frame Returns - Restarts particular call frame from the beginning. The old, deprecated behavior of ‘restartFrame’ is to stay paused and allow further CDP commands after a restart was scheduled. This can cause problems with restarting, so we now continue execution immediatly after it has been scheduled until we reach the beginning of the restarted frame.
- Resume
Params - Resumes JavaScript execution.
- Scope
- Scope description.
- Script
Position - Location in the source code.
- Search
InContent Params - Searches for given string in script content.
- Search
InContent Returns - Searches for given string in script content.
- Search
Match - Search match for resource.
- SetAsync
Call Stack Depth Params - Enables or disables async call stacks tracking.
- SetBlackbox
Execution Contexts Params - Replace previous blackbox execution contexts with passed ones. Forces backend to skip stepping/pausing in scripts in these execution contexts. VM will try to leave blackboxed script by performing ‘step in’ several times, finally resorting to ‘step out’ if unsuccessful.
- SetBlackbox
Patterns Params - Replace previous blackbox patterns with passed ones. Forces backend to skip stepping/pausing in scripts with url matching one of the patterns. VM will try to leave blackboxed script by performing ‘step in’ several times, finally resorting to ‘step out’ if unsuccessful.
- SetBlackboxed
Ranges Params - Makes backend skip steps in the script in blackboxed ranges. VM will try leave blacklisted scripts by performing ‘step in’ several times, finally resorting to ‘step out’ if unsuccessful. Positions array contains positions where blackbox state is changed. First interval isn’t blackboxed. Array should be sorted.
- SetBreakpoint
ByUrl Params - Sets JavaScript breakpoint at given location specified either by URL or URL regex. Once this command is issued, all existing parsed scripts will have breakpoints resolved and returned in ‘locations’ property. Further matching script parsing will result in subsequent ‘breakpointResolved’ events issued. This logical breakpoint will survive page reloads.
- SetBreakpoint
ByUrl Returns - Sets JavaScript breakpoint at given location specified either by URL or URL regex. Once this command is issued, all existing parsed scripts will have breakpoints resolved and returned in ‘locations’ property. Further matching script parsing will result in subsequent ‘breakpointResolved’ events issued. This logical breakpoint will survive page reloads.
- SetBreakpoint
OnFunction Call Params - Sets JavaScript breakpoint before each call to the given function. If another function was created from the same source as a given one, calling it will also trigger the breakpoint.
- SetBreakpoint
OnFunction Call Returns - Sets JavaScript breakpoint before each call to the given function. If another function was created from the same source as a given one, calling it will also trigger the breakpoint.
- SetBreakpoint
Params - Sets JavaScript breakpoint at a given location.
- SetBreakpoint
Returns - Sets JavaScript breakpoint at a given location.
- SetBreakpoints
Active Params - Activates / deactivates all breakpoints on the page.
- SetInstrumentation
Breakpoint Params - Sets instrumentation breakpoint.
- SetInstrumentation
Breakpoint Returns - Sets instrumentation breakpoint.
- SetPause
OnExceptions Params - Defines pause on exceptions state. Can be set to stop on all exceptions, uncaught exceptions, or caught exceptions, no exceptions. Initial pause on exceptions state is ‘none’.
- SetReturn
Value Params - Changes return value in top frame. Available only at return break position.
- SetScript
Source Params - Edits JavaScript source live.
- SetScript
Source Returns - Edits JavaScript source live.
- SetSkip
AllPauses Params - Makes page not interrupt on any pauses (breakpoint, exception, dom exception etc).
- SetVariable
Value Params - Changes value of variable in a callframe. Object-based scopes are not supported and must be mutated manually.
- Step
Into Params - Steps into the function call.
- Step
OutParams - Step
Over Params - Steps over the statement.
- Wasm
Disassembly Chunk
Enums
- Script
Language - Enum of possible script languages.
Type Aliases
- Breakpoint
Id - Breakpoint identifier.
- Call
Frame Id - Call frame identifier.