pub struct CallFrame<'a> { /* private fields */ }Expand description
JavaScript call frame. Array of call frames form the call stack.
Implementations
Sourceimpl<'a> CallFrame<'a>
impl<'a> CallFrame<'a>
Sourcepub fn builder(
call_frame_id: impl Into<CallFrameId<'a>>,
function_name: impl Into<Cow<'a, str>>,
location: Location<'a>,
url: impl Into<Cow<'a, str>>,
scope_chain: Vec<Scope<'a>>,
this: RemoteObject<'a>,
) -> CallFrameBuilder<'a>
pub fn builder( call_frame_id: impl Into<CallFrameId<'a>>, function_name: impl Into<Cow<'a, str>>, location: Location<'a>, url: impl Into<Cow<'a, str>>, scope_chain: Vec<Scope<'a>>, this: RemoteObject<'a>, ) -> CallFrameBuilder<'a>
Creates a builder for this type with the required parameters:
call_frame_id: Call frame identifier. This identifier is only valid while the virtual machine is paused.function_name: Name of the JavaScript function called on this call frame.location: Location in the source code.url: JavaScript script name or url. Deprecated in favor of using thelocation.scriptIdto resolve the URL via a previously sentDebugger.scriptParsedevent.scope_chain: Scope chain for this call frame.this:thisobject for this call frame.
Sourcepub fn call_frame_id(&self) -> &CallFrameId<'a>
pub fn call_frame_id(&self) -> &CallFrameId<'a>
Call frame identifier. This identifier is only valid while the virtual machine is paused.
Sourcepub fn function_name(&self) -> &str
pub fn function_name(&self) -> &str
Name of the JavaScript function called on this call frame.
Sourcepub fn function_location(&self) -> Option<&Location<'a>>
pub fn function_location(&self) -> Option<&Location<'a>>
Location in the source code.
Sourcepub fn url(&self) -> &str
pub fn url(&self) -> &str
JavaScript script name or url. Deprecated in favor of using the ‘location.scriptId’ to resolve the URL via a previously sent ‘Debugger.scriptParsed’ event.
Sourcepub fn scope_chain(&self) -> &[Scope<'a>]
pub fn scope_chain(&self) -> &[Scope<'a>]
Scope chain for this call frame.
Sourcepub fn this(&self) -> &RemoteObject<'a>
pub fn this(&self) -> &RemoteObject<'a>
‘this’ object for this call frame.
Sourcepub fn return_value(&self) -> Option<&RemoteObject<'a>>
pub fn return_value(&self) -> Option<&RemoteObject<'a>>
The value being returned, if the function is at return point.
Sourcepub fn can_be_restarted(&self) -> Option<bool>
pub fn can_be_restarted(&self) -> Option<bool>
Valid only while the VM is paused and indicates whether this frame can be restarted or not. Note that a ‘true’ value here does not guarantee that Debugger#restartFrame with this CallFrameId will be successful, but it is very likely.