pub struct CallFrame {
pub callFrameId: CallFrameId,
pub functionName: String,
pub functionLocation: Option<Location>,
pub location: Location,
pub url: String,
pub scopeChain: Vec<Scope>,
pub this: RemoteObject,
pub returnValue: Option<RemoteObject>,
pub canBeRestarted: Option<bool>,
}Expand description
JavaScript call frame. Array of call frames form the call stack.
Fields
callFrameId: CallFrameIdCall frame identifier. This identifier is only valid while the virtual machine is paused.
functionName: StringName of the JavaScript function called on this call frame.
functionLocation: Option<Location>Location in the source code.
location: LocationLocation in the source code.
url: StringJavaScript script name or url. Deprecated in favor of using the ‘location.scriptId’ to resolve the URL via a previously sent ‘Debugger.scriptParsed’ event.
scopeChain: Vec<Scope>Scope chain for this call frame.
this: RemoteObject‘this’ object for this call frame.
returnValue: Option<RemoteObject>The value being returned, if the function is at return point.
canBeRestarted: Option<bool>Valid only while the VM is paused and indicates whether this frame can be restarted or not. Note that a ‘true’ value here does not guarantee that Debugger#restartFrame with this CallFrameId will be successful, but it is very likely.