pub struct CallFrameBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> CallFrameBuilder<'a>
impl<'a> CallFrameBuilder<'a>
Sourcepub fn function_location(self, function_location: Location<'a>) -> Self
pub fn function_location(self, function_location: Location<'a>) -> Self
Location in the source code.
Sourcepub fn return_value(self, return_value: RemoteObject<'a>) -> Self
pub fn return_value(self, return_value: RemoteObject<'a>) -> Self
The value being returned, if the function is at return point.
Sourcepub fn can_be_restarted(self, can_be_restarted: bool) -> Self
pub fn can_be_restarted(self, can_be_restarted: bool) -> Self
Valid only while the VM is paused and indicates whether this frame can be restarted or not. Note that a ‘true’ value here does not guarantee that Debugger#restartFrame with this CallFrameId will be successful, but it is very likely.
pub fn build(self) -> CallFrame<'a>