pub struct EvaluateOnCallFrameParams<'a> { /* private fields */ }Expand description
Evaluates expression on a given call frame.
Implementations
Sourceimpl<'a> EvaluateOnCallFrameParams<'a>
impl<'a> EvaluateOnCallFrameParams<'a>
Sourcepub fn builder(
call_frame_id: impl Into<CallFrameId<'a>>,
expression: impl Into<Cow<'a, str>>,
) -> EvaluateOnCallFrameParamsBuilder<'a>
pub fn builder( call_frame_id: impl Into<CallFrameId<'a>>, expression: impl Into<Cow<'a, str>>, ) -> EvaluateOnCallFrameParamsBuilder<'a>
Creates a builder for this type with the required parameters:
call_frame_id: Call frame identifier to evaluate on.expression: Expression to evaluate.
Sourcepub fn call_frame_id(&self) -> &CallFrameId<'a>
pub fn call_frame_id(&self) -> &CallFrameId<'a>
Call frame identifier to evaluate on.
Sourcepub fn expression(&self) -> &str
pub fn expression(&self) -> &str
Expression to evaluate.
Sourcepub fn object_group(&self) -> Option<&str>
pub fn object_group(&self) -> Option<&str>
String object group name to put result into (allows rapid releasing resulting object handles using ‘releaseObjectGroup’).
Sourcepub fn include_command_line_api(&self) -> Option<bool>
pub fn include_command_line_api(&self) -> Option<bool>
Specifies whether command line API should be available to the evaluated expression, defaults to false.
Sourcepub fn silent(&self) -> Option<bool>
pub fn silent(&self) -> Option<bool>
In silent mode exceptions thrown during evaluation are not reported and do not pause execution. Overrides ‘setPauseOnException’ state.
Sourcepub fn return_by_value(&self) -> Option<bool>
pub fn return_by_value(&self) -> Option<bool>
Whether the result is expected to be a JSON object that should be sent by value.
Sourcepub fn generate_preview(&self) -> Option<bool>
pub fn generate_preview(&self) -> Option<bool>
Whether preview should be generated for the result.
Sourcepub fn throw_on_side_effect(&self) -> Option<bool>
pub fn throw_on_side_effect(&self) -> Option<bool>
Whether to throw an exception if side effect cannot be ruled out during evaluation.