pub struct RestartFrameParams<'a> { /* private fields */ }Expand description
Restarts particular call frame from the beginning. The old, deprecated behavior of ‘restartFrame’ is to stay paused and allow further CDP commands after a restart was scheduled. This can cause problems with restarting, so we now continue execution immediatly after it has been scheduled until we reach the beginning of the restarted frame.
To stay back-wards compatible, ‘restartFrame’ now expects a ‘mode’ parameter to be present. If the ‘mode’ parameter is missing, ‘restartFrame’ errors out.
The various return values are deprecated and ‘callFrames’ is always empty. Use the call frames from the ‘Debugger#paused’ events instead, that fires once V8 pauses at the beginning of the restarted function.
Implementations
Sourceimpl<'a> RestartFrameParams<'a>
impl<'a> RestartFrameParams<'a>
Sourcepub fn builder(
call_frame_id: impl Into<CallFrameId<'a>>,
) -> RestartFrameParamsBuilder<'a>
pub fn builder( call_frame_id: impl Into<CallFrameId<'a>>, ) -> RestartFrameParamsBuilder<'a>
Creates a builder for this type with the required parameters:
call_frame_id: Call frame identifier to evaluate on.
Sourcepub fn call_frame_id(&self) -> &CallFrameId<'a>
pub fn call_frame_id(&self) -> &CallFrameId<'a>
Call frame identifier to evaluate on.