pub struct Scope {
pub type_: String,
pub object: RemoteObject,
pub name: Option<String>,
pub startLocation: Option<Location>,
pub endLocation: Option<Location>,
}Expand description
Scope description.
Fields
type_: StringScope type.
object: RemoteObjectObject representing the scope. For ‘global’ and ‘with’ scopes it represents the actual object; for the rest of the scopes, it is artificial transient object enumerating scope variables as its properties.
name: Option<String>startLocation: Option<Location>Location in the source code where scope starts
endLocation: Option<Location>Location in the source code where scope ends