pub struct SetBlackboxExecutionContextsParams {
pub uniqueIds: Vec<String>,
}Expand description
Replace previous blackbox execution contexts with passed ones. Forces backend to skip stepping/pausing in scripts in these execution contexts. VM will try to leave blackboxed script by performing ‘step in’ several times, finally resorting to ‘step out’ if unsuccessful.
Fields
uniqueIds: Vec<String>Array of execution context unique ids for the debugger to ignore.
Implementations