SetBlackboxPatternsParams

Struct SetBlackboxPatternsParams 

pub struct SetBlackboxPatternsParams<'a> { /* private fields */ }
Replace previous blackbox patterns with passed ones. Forces backend to skip stepping/pausing in scripts with url matching one of the patterns. VM will try to leave blackboxed script by performing ‘step in’ several times, finally resorting to ‘step out’ if unsuccessful.

Implementations

Source

impl<'a> SetBlackboxPatternsParams<'a>

pub fn builder( patterns: Vec<Cow<'a, str>>, ) -> SetBlackboxPatternsParamsBuilder<'a>

Creates a builder for this type with the required parameters:

  • patterns: Array of regexps that will be used to check script url for blackbox state.
pub fn patterns(&self) -> &[Cow<'a, str>]

Array of regexps that will be used to check script url for blackbox state.

pub fn skip_anonymous(&self) -> Option<bool>

If true, also ignore scripts with no source url.

Source

impl<'a> SetBlackboxPatternsParams<'a>

pub const METHOD: &'static str = "Debugger.setBlackboxPatterns"