SetBlackboxedRangesParams

Struct SetBlackboxedRangesParams 

pub struct SetBlackboxedRangesParams {
    pub scriptId: ScriptId,
    pub positions: Vec<ScriptPosition>,
}
Makes backend skip steps in the script in blackboxed ranges. VM will try leave blacklisted scripts by performing ‘step in’ several times, finally resorting to ‘step out’ if unsuccessful. Positions array contains positions where blackbox state is changed. First interval isn’t blackboxed. Array should be sorted.

Fields

scriptId: ScriptId

Id of the script.

positions: Vec<ScriptPosition>

Implementations

Source

impl SetBlackboxedRangesParams

pub const METHOD: &'static str = "Debugger.setBlackboxedRanges"