pub struct SetBlackboxedRangesParams {
pub scriptId: ScriptId,
pub positions: Vec<ScriptPosition>,
}Expand description
Makes backend skip steps in the script in blackboxed ranges. VM will try leave blacklisted scripts by performing ‘step in’ several times, finally resorting to ‘step out’ if unsuccessful. Positions array contains positions where blackbox state is changed. First interval isn’t blackboxed. Array should be sorted.
Fields
scriptId: ScriptIdId of the script.
positions: Vec<ScriptPosition>Trait Implementations
Sourceimpl Clone for SetBlackboxedRangesParams
impl Clone for SetBlackboxedRangesParams
Sourcefn clone(&self) -> SetBlackboxedRangesParams
fn clone(&self) -> SetBlackboxedRangesParams
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SetBlackboxedRangesParams
impl Debug for SetBlackboxedRangesParams
Sourceimpl Default for SetBlackboxedRangesParams
impl Default for SetBlackboxedRangesParams
Sourcefn default() -> SetBlackboxedRangesParams
fn default() -> SetBlackboxedRangesParams
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for SetBlackboxedRangesParams
impl<'de> Deserialize<'de> for SetBlackboxedRangesParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more