SetBreakpointByUrlParams

Struct SetBreakpointByUrlParams 

pub struct SetBreakpointByUrlParams<'a> { /* private fields */ }
Sets JavaScript breakpoint at given location specified either by URL or URL regex. Once this command is issued, all existing parsed scripts will have breakpoints resolved and returned in ‘locations’ property. Further matching script parsing will result in subsequent ‘breakpointResolved’ events issued. This logical breakpoint will survive page reloads.

Implementations

Source

impl<'a> SetBreakpointByUrlParams<'a>

pub fn builder(line_number: i64) -> SetBreakpointByUrlParamsBuilder<'a>

Creates a builder for this type with the required parameters:

  • line_number: Line number to set breakpoint at.
pub fn line_number(&self) -> i64

Line number to set breakpoint at.

pub fn url(&self) -> Option<&str>

URL of the resources to set breakpoint on.

pub fn url_regex(&self) -> Option<&str>

Regex pattern for the URLs of the resources to set breakpoints on. Either ‘url’ or ‘urlRegex’ must be specified.

pub fn script_hash(&self) -> Option<&str>

Script hash of the resources to set breakpoint on.

pub fn column_number(&self) -> Option<i64>

Offset in the line to set breakpoint at.

pub fn condition(&self) -> Option<&str>

Expression to use as a breakpoint condition. When specified, debugger will only stop on the breakpoint if this expression evaluates to true.

Source

impl<'a> SetBreakpointByUrlParams<'a>

pub const METHOD: &'static str = "Debugger.setBreakpointByUrl"