pub struct SetBreakpointByUrlParams {
pub lineNumber: i64,
pub url: Option<String>,
pub urlRegex: Option<String>,
pub scriptHash: Option<String>,
pub columnNumber: Option<i64>,
pub condition: Option<String>,
}Expand description
Sets JavaScript breakpoint at given location specified either by URL or URL regex. Once this command is issued, all existing parsed scripts will have breakpoints resolved and returned in ‘locations’ property. Further matching script parsing will result in subsequent ‘breakpointResolved’ events issued. This logical breakpoint will survive page reloads.
Fields
lineNumber: i64Line number to set breakpoint at.
url: Option<String>URL of the resources to set breakpoint on.
urlRegex: Option<String>Regex pattern for the URLs of the resources to set breakpoints on. Either ‘url’ or ‘urlRegex’ must be specified.
scriptHash: Option<String>Script hash of the resources to set breakpoint on.
columnNumber: Option<i64>Offset in the line to set breakpoint at.
condition: Option<String>Expression to use as a breakpoint condition. When specified, debugger will only stop on the breakpoint if this expression evaluates to true.