pub struct SetBreakpointByUrlReturns<'a> { /* private fields */ }Expand description
Sets JavaScript breakpoint at given location specified either by URL or URL regex. Once this command is issued, all existing parsed scripts will have breakpoints resolved and returned in ‘locations’ property. Further matching script parsing will result in subsequent ‘breakpointResolved’ events issued. This logical breakpoint will survive page reloads.
Implementations
Sourceimpl<'a> SetBreakpointByUrlReturns<'a>
impl<'a> SetBreakpointByUrlReturns<'a>
Sourcepub fn builder(
breakpoint_id: impl Into<BreakpointId<'a>>,
locations: Vec<Location<'a>>,
) -> SetBreakpointByUrlReturnsBuilder<'a>
pub fn builder( breakpoint_id: impl Into<BreakpointId<'a>>, locations: Vec<Location<'a>>, ) -> SetBreakpointByUrlReturnsBuilder<'a>
Creates a builder for this type with the required parameters:
breakpoint_id: Id of the created breakpoint for further reference.locations: List of the locations this breakpoint resolved into upon addition.
Sourcepub fn breakpoint_id(&self) -> &BreakpointId<'a>
pub fn breakpoint_id(&self) -> &BreakpointId<'a>
Id of the created breakpoint for further reference.