pub struct SetBreakpointOnFunctionCallParams<'a> { /* private fields */ }Expand description
Sets JavaScript breakpoint before each call to the given function. If another function was created from the same source as a given one, calling it will also trigger the breakpoint.
Implementations
Sourceimpl<'a> SetBreakpointOnFunctionCallParams<'a>
impl<'a> SetBreakpointOnFunctionCallParams<'a>
Sourcepub fn builder(
object_id: RemoteObjectId<'a>,
) -> SetBreakpointOnFunctionCallParamsBuilder<'a>
pub fn builder( object_id: RemoteObjectId<'a>, ) -> SetBreakpointOnFunctionCallParamsBuilder<'a>
Creates a builder for this type with the required parameters:
object_id: Function object id.
Sourcepub fn object_id(&self) -> &RemoteObjectId<'a>
pub fn object_id(&self) -> &RemoteObjectId<'a>
Function object id.