pub struct SetBreakpointOnFunctionCallReturns {
pub breakpointId: BreakpointId,
}Expand description
Sets JavaScript breakpoint before each call to the given function. If another function was created from the same source as a given one, calling it will also trigger the breakpoint.
Fields
breakpointId: BreakpointIdId of the created breakpoint for further reference.