pub struct SetScriptSourceParamsBuilder<'a> { /* private fields */ }Implementations
Sourceimpl<'a> SetScriptSourceParamsBuilder<'a>
impl<'a> SetScriptSourceParamsBuilder<'a>
Sourcepub fn dry_run(self, dry_run: bool) -> Self
pub fn dry_run(self, dry_run: bool) -> Self
If true the change will not actually be applied. Dry run may be used to get result description without actually modifying the code.
Sourcepub fn allow_top_frame_editing(self, allow_top_frame_editing: bool) -> Self
pub fn allow_top_frame_editing(self, allow_top_frame_editing: bool) -> Self
If true, then ‘scriptSource’ is allowed to change the function on top of the stack as long as the top-most stack frame is the only activation of that function.
pub fn build(self) -> SetScriptSourceParams<'a>