pub struct SetScriptSourceReturns {
pub callFrames: Option<Vec<CallFrame>>,
pub stackChanged: Option<bool>,
pub asyncStackTrace: Option<StackTrace>,
pub asyncStackTraceId: Option<StackTraceId>,
pub status: String,
pub exceptionDetails: Option<ExceptionDetails>,
}Expand description
Edits JavaScript source live.
In general, functions that are currently on the stack can not be edited with a single exception: If the edited function is the top-most stack frame and that is the only activation of that function on the stack. In this case the live edit will be successful and a ‘Debugger.restartFrame’ for the top-most function is automatically triggered.
Fields
callFrames: Option<Vec<CallFrame>>New stack trace in case editing has happened while VM was stopped.
stackChanged: Option<bool>Whether current call stack was modified after applying the changes.
asyncStackTrace: Option<StackTrace>Async stack trace, if any.
asyncStackTraceId: Option<StackTraceId>Async stack trace, if any.
status: StringWhether the operation was successful or not. Only ‘Ok’ denotes a successful live edit while the other enum variants denote why the live edit failed.
exceptionDetails: Option<ExceptionDetails>Exception details if any. Only present when ‘status’ is ‘CompileError’.