pub struct SetScriptSourceReturns<'a> { /* private fields */ }Expand description
Edits JavaScript source live.
In general, functions that are currently on the stack can not be edited with a single exception: If the edited function is the top-most stack frame and that is the only activation of that function on the stack. In this case the live edit will be successful and a ‘Debugger.restartFrame’ for the top-most function is automatically triggered.
Implementations
Sourceimpl<'a> SetScriptSourceReturns<'a>
impl<'a> SetScriptSourceReturns<'a>
Sourcepub fn builder(
status: impl Into<Cow<'a, str>>,
) -> SetScriptSourceReturnsBuilder<'a>
pub fn builder( status: impl Into<Cow<'a, str>>, ) -> SetScriptSourceReturnsBuilder<'a>
Creates a builder for this type with the required parameters:
status: Whether the operation was successful or not. OnlyOkdenotes a successful live edit while the other enum variants denote why the live edit failed.
Sourcepub fn call_frames(&self) -> Option<&[CallFrame<'a>]>
pub fn call_frames(&self) -> Option<&[CallFrame<'a>]>
New stack trace in case editing has happened while VM was stopped.
Sourcepub fn stack_changed(&self) -> Option<bool>
pub fn stack_changed(&self) -> Option<bool>
Whether current call stack was modified after applying the changes.
Sourcepub fn async_stack_trace(&self) -> Option<&StackTrace<'a>>
pub fn async_stack_trace(&self) -> Option<&StackTrace<'a>>
Async stack trace, if any.
Sourcepub fn async_stack_trace_id(&self) -> Option<&StackTraceId<'a>>
pub fn async_stack_trace_id(&self) -> Option<&StackTraceId<'a>>
Async stack trace, if any.
Sourcepub fn status(&self) -> &str
pub fn status(&self) -> &str
Whether the operation was successful or not. Only ‘Ok’ denotes a successful live edit while the other enum variants denote why the live edit failed.
Sourcepub fn exception_details(&self) -> Option<&ExceptionDetails<'a>>
pub fn exception_details(&self) -> Option<&ExceptionDetails<'a>>
Exception details if any. Only present when ‘status’ is ‘CompileError’.