SetScriptSourceReturnsBuilder

Struct SetScriptSourceReturnsBuilder 

pub struct SetScriptSourceReturnsBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> SetScriptSourceReturnsBuilder<'a>

pub fn call_frames(self, call_frames: Vec<CallFrame<'a>>) -> Self

New stack trace in case editing has happened while VM was stopped.

pub fn stack_changed(self, stack_changed: bool) -> Self

Whether current call stack was modified after applying the changes.

pub fn async_stack_trace(self, async_stack_trace: StackTrace<'a>) -> Self

Async stack trace, if any.

pub fn async_stack_trace_id( self, async_stack_trace_id: StackTraceId<'a>, ) -> Self

Async stack trace, if any.

pub fn exception_details(self, exception_details: ExceptionDetails<'a>) -> Self

Exception details if any. Only present when ‘status’ is ‘CompileError’.

pub fn build(self) -> SetScriptSourceReturns<'a>