pub struct SetVariableValueParams<'a> { /* private fields */ }Expand description
Changes value of variable in a callframe. Object-based scopes are not supported and must be mutated manually.
Implementations
Sourceimpl<'a> SetVariableValueParams<'a>
impl<'a> SetVariableValueParams<'a>
Sourcepub fn builder(
scope_number: i64,
variable_name: impl Into<Cow<'a, str>>,
new_value: CallArgument<'a>,
call_frame_id: impl Into<CallFrameId<'a>>,
) -> SetVariableValueParamsBuilder<'a>
pub fn builder( scope_number: i64, variable_name: impl Into<Cow<'a, str>>, new_value: CallArgument<'a>, call_frame_id: impl Into<CallFrameId<'a>>, ) -> SetVariableValueParamsBuilder<'a>
Creates a builder for this type with the required parameters:
scope_number: 0-based number of scope as was listed in scope chain. Only ‘local’, ‘closure’ and ‘catch’ scope types are allowed. Other scopes could be manipulated manually.variable_name: Variable name.new_value: New variable value.call_frame_id: Id of callframe that holds variable.
Sourcepub fn scope_number(&self) -> i64
pub fn scope_number(&self) -> i64
0-based number of scope as was listed in scope chain. Only ‘local’, ‘closure’ and ‘catch’ scope types are allowed. Other scopes could be manipulated manually.
Sourcepub fn variable_name(&self) -> &str
pub fn variable_name(&self) -> &str
Variable name.
Sourcepub fn new_value(&self) -> &CallArgument<'a>
pub fn new_value(&self) -> &CallArgument<'a>
New variable value.
Sourcepub fn call_frame_id(&self) -> &CallFrameId<'a>
pub fn call_frame_id(&self) -> &CallFrameId<'a>
Id of callframe that holds variable.