pub struct SetVariableValueParams {
pub scopeNumber: i64,
pub variableName: String,
pub newValue: CallArgument,
pub callFrameId: CallFrameId,
}Expand description
Changes value of variable in a callframe. Object-based scopes are not supported and must be mutated manually.
Fields
scopeNumber: i640-based number of scope as was listed in scope chain. Only ‘local’, ‘closure’ and ‘catch’ scope types are allowed. Other scopes could be manipulated manually.
variableName: StringVariable name.
newValue: CallArgumentNew variable value.
callFrameId: CallFrameIdId of callframe that holds variable.