pub struct SamplingHeapProfileNode {
pub callFrame: CallFrame,
pub selfSize: f64,
pub id: u64,
pub children: Vec<SamplingHeapProfileNode>,
}Expand description
Sampling Heap Profile node. Holds callsite information, allocation statistics and child nodes.
Fields
callFrame: CallFrameFunction location.
selfSize: f64Allocations size in bytes for the node excluding children.
id: u64Node id. Ids are unique across all profiles collected between startSampling and stopSampling.
children: Vec<SamplingHeapProfileNode>Child nodes.