pub struct StopTrackingHeapObjectsParams {
pub reportProgress: Option<bool>,
pub treatGlobalObjectsAsRoots: Option<bool>,
pub captureNumericValue: Option<bool>,
pub exposeInternals: Option<bool>,
}Fields
reportProgress: Option<bool>If true ‘reportHeapSnapshotProgress’ events will be generated while snapshot is being taken when the tracking is stopped.
treatGlobalObjectsAsRoots: Option<bool>Deprecated in favor of ‘exposeInternals’.
captureNumericValue: Option<bool>If true, numerical values are included in the snapshot
exposeInternals: Option<bool>If true, exposes internals of the snapshot.