StopTrackingHeapObjectsParamsBuilder

Struct StopTrackingHeapObjectsParamsBuilder 

pub struct StopTrackingHeapObjectsParamsBuilder { /* private fields */ }

Implementations

Source

impl StopTrackingHeapObjectsParamsBuilder

pub fn report_progress(self, report_progress: bool) -> Self

If true ‘reportHeapSnapshotProgress’ events will be generated while snapshot is being taken when the tracking is stopped.

pub fn treat_global_objects_as_roots( self, treat_global_objects_as_roots: bool, ) -> Self

Deprecated in favor of ‘exposeInternals’.

pub fn capture_numeric_value(self, capture_numeric_value: bool) -> Self

If true, numerical values are included in the snapshot

pub fn expose_internals(self, expose_internals: bool) -> Self

If true, exposes internals of the snapshot.

pub fn build(self) -> StopTrackingHeapObjectsParams