Structs
- Coverage
Range - Coverage data for a source range.
- Disable
Params - Enable
Params - Function
Coverage - Coverage data for a JavaScript function.
- GetBest
Effort Coverage Params - GetBest
Effort Coverage Returns - Collect coverage data for the current isolate. The coverage data may be incomplete due to garbage collection.
- Position
Tick Info - Specifies a number of samples attributed to a certain source position.
- Profile
- Profile.
- Profile
Node - Profile node. Holds callsite information, execution statistics and child nodes.
- Script
Coverage - Coverage data for a JavaScript script.
- SetSampling
Interval Params - Changes CPU profiler sampling interval. Must be called before CPU profiles recording started.
- Start
Params - Start
Precise Coverage Params - Enable precise code coverage. Coverage data for JavaScript executed before enabling precise code coverage may be incomplete. Enabling prevents running optimized code and resets execution counters.
- Start
Precise Coverage Returns - Enable precise code coverage. Coverage data for JavaScript executed before enabling precise code coverage may be incomplete. Enabling prevents running optimized code and resets execution counters.
- Stop
Params - Stop
Precise Coverage Params - Stop
Returns - Take
Precise Coverage Params - Take
Precise Coverage Returns - Collect coverage data for the current isolate, and resets execution counters. Precise code coverage needs to have started.