Module profiler

Module profiler 

Structs

CoverageRange
Coverage data for a source range.
FunctionCoverage
Coverage data for a JavaScript function.
GetBestEffortCoverageReturns
Collect coverage data for the current isolate. The coverage data may be incomplete due to garbage collection.
PositionTickInfo
Specifies a number of samples attributed to a certain source position.
Profile
Profile.
ProfileNode
Profile node. Holds callsite information, execution statistics and child nodes.
ScriptCoverage
Coverage data for a JavaScript script.
SetSamplingIntervalParams
Changes CPU profiler sampling interval. Must be called before CPU profiles recording started.
StartPreciseCoverageParams
Enable precise code coverage. Coverage data for JavaScript executed before enabling precise code coverage may be incomplete. Enabling prevents running optimized code and resets execution counters.
StartPreciseCoverageReturns
Enable precise code coverage. Coverage data for JavaScript executed before enabling precise code coverage may be incomplete. Enabling prevents running optimized code and resets execution counters.
StopReturns
TakePreciseCoverageReturns
Collect coverage data for the current isolate, and resets execution counters. Precise code coverage needs to have started.