pub struct StartPreciseCoverageParams { /* private fields */ }Expand description
Enable precise code coverage. Coverage data for JavaScript executed before enabling precise code coverage may be incomplete. Enabling prevents running optimized code and resets execution counters.
Implementations
Sourceimpl StartPreciseCoverageParams
impl StartPreciseCoverageParams
Sourcepub fn builder() -> StartPreciseCoverageParamsBuilder
pub fn builder() -> StartPreciseCoverageParamsBuilder
Creates a builder for this type.
Sourcepub fn call_count(&self) -> Option<bool>
pub fn call_count(&self) -> Option<bool>
Collect accurate call counts beyond simple ‘covered’ or ‘not covered’.
Sourcepub fn allow_triggered_updates(&self) -> Option<bool>
pub fn allow_triggered_updates(&self) -> Option<bool>
Allow the backend to send updates on its own initiative