Runtime domain exposes JavaScript runtime by means of remote evaluation and mirror objects. Evaluation results are returned as mirror object that expose object type, string representation and unique identifier that can be used for further object reference. Original objects are maintained in memory unless they are either explicitly released or are released along with the other objects in their object group.
Structs
- AddBinding
Params - If executionContextId is empty, adds binding with the given name on the global objects of all inspected contexts, including those created later, bindings survive reloads. Binding function takes exactly one argument, this argument should be string, in case of any other input, function throws an exception. Each binding function call produces Runtime.bindingCalled notification.
- AddBinding
Params Builder - Await
Promise Params - Add handler to promise with given promise object id.
- Await
Promise Params Builder - Await
Promise Returns - Add handler to promise with given promise object id.
- Await
Promise Returns Builder - Call
Argument - Represents function call argument. Either remote object id ‘objectId’, primitive ‘value’, unserializable primitive value or neither of (for undefined) them should be specified.
- Call
Argument Builder - Call
Frame - Stack entry for runtime errors and assertions.
- Call
Frame Builder - Call
Function OnParams - Calls function with given declaration on the given object. Object group of the result is inherited from the target object.
- Call
Function OnParams Builder - Call
Function OnReturns - Calls function with given declaration on the given object. Object group of the result is inherited from the target object.
- Call
Function OnReturns Builder - Compile
Script Params - Compiles expression.
- Compile
Script Params Builder - Compile
Script Returns - Compiles expression.
- Compile
Script Returns Builder - Custom
Preview - Custom
Preview Builder - Deep
Serialized Value - Represents deep serialized value.
- Deep
Serialized Value Builder - Disable
Params - Discard
Console Entries Params - Enable
Params - Entry
Preview - Entry
Preview Builder - Evaluate
Params - Evaluates expression on global object.
- Evaluate
Params Builder - Evaluate
Returns - Evaluates expression on global object.
- Evaluate
Returns Builder - Exception
Details - Detailed information about exception (or error) that was thrown during script compilation or execution.
- Exception
Details Builder - Execution
Context Description - Description of an isolated world.
- Execution
Context Description Builder - GetException
Details Params - This method tries to lookup and populate exception details for a JavaScript Error object. Note that the stackTrace portion of the resulting exceptionDetails will only be populated if the Runtime domain was enabled at the time when the Error was thrown.
- GetException
Details Params Builder - GetException
Details Returns - This method tries to lookup and populate exception details for a JavaScript Error object. Note that the stackTrace portion of the resulting exceptionDetails will only be populated if the Runtime domain was enabled at the time when the Error was thrown.
- GetException
Details Returns Builder - GetHeap
Usage Params - GetHeap
Usage Returns - Returns the JavaScript heap usage. It is the total usage of the corresponding isolate not scoped to a particular Runtime.
- GetHeap
Usage Returns Builder - GetIsolate
IdParams - GetIsolate
IdReturns - Returns the isolate id.
- GetIsolate
IdReturns Builder - GetProperties
Params - Returns properties of a given object. Object group of the result is inherited from the target object.
- GetProperties
Params Builder - GetProperties
Returns - Returns properties of a given object. Object group of the result is inherited from the target object.
- GetProperties
Returns Builder - Global
Lexical Scope Names Params - Returns all let, const and class variables from global scope.
- Global
Lexical Scope Names Params Builder - Global
Lexical Scope Names Returns - Returns all let, const and class variables from global scope.
- Global
Lexical Scope Names Returns Builder - Internal
Property Descriptor - Object internal property descriptor. This property isn’t normally visible in JavaScript code.
- Internal
Property Descriptor Builder - Object
Preview - Object containing abbreviated remote object value.
- Object
Preview Builder - Private
Property Descriptor - Object private field descriptor.
- Private
Property Descriptor Builder - Property
Descriptor - Object property descriptor.
- Property
Descriptor Builder - Property
Preview - Property
Preview Builder - Query
Objects Params - Query
Objects Params Builder - Query
Objects Returns - Query
Objects Returns Builder - Release
Object Group Params - Releases all remote objects that belong to a given group.
- Release
Object Group Params Builder - Release
Object Params - Releases remote object with given id.
- Release
Object Params Builder - Remote
Object - Mirror object referencing original JavaScript object.
- Remote
Object Builder - Remove
Binding Params - This method does not remove binding function from global object but unsubscribes current runtime agent from Runtime.bindingCalled notifications.
- Remove
Binding Params Builder - RunIf
Waiting ForDebugger Params - RunScript
Params - Runs script with given id in a given context.
- RunScript
Params Builder - RunScript
Returns - Runs script with given id in a given context.
- RunScript
Returns Builder - Serialization
Options - Represents options for serialization. Overrides ‘generatePreview’ and ‘returnByValue’.
- Serialization
Options Builder - SetAsync
Call Stack Depth Params - Enables or disables async call stacks tracking.
- SetAsync
Call Stack Depth Params Builder - SetCustom
Object Formatter Enabled Params - SetCustom
Object Formatter Enabled Params Builder - SetMax
Call Stack Size ToCapture Params - SetMax
Call Stack Size ToCapture Params Builder - Stack
Trace - Call frames for assertions or error messages.
- Stack
Trace Builder - Stack
Trace Id - If ‘debuggerId’ is set stack trace comes from another debugger and can be resolved there. This allows to track cross-debugger calls. See ‘Runtime.StackTrace’ and ‘Debugger.paused’ for usages.
- Stack
Trace IdBuilder - Terminate
Execution Params
Type Aliases
- Execution
Context Id - Id of an execution context.
- Remote
Object Id - Unique object identifier.
- Script
Id - Unique script identifier.
- Time
Delta - Number of milliseconds.
- Timestamp
- Number of milliseconds since epoch.
- Unique
Debugger Id - Unique identifier of current debugger.
- Unserializable
Value - Primitive value which cannot be JSON-stringified. Includes values ‘-0’, ‘NaN’, ‘Infinity’, ‘-Infinity’, and bigint literals.