Runtime domain exposes JavaScript runtime by means of remote evaluation and mirror objects. Evaluation results are returned as mirror object that expose object type, string representation and unique identifier that can be used for further object reference. Original objects are maintained in memory unless they are either explicitly released or are released along with the other objects in their object group.
Structs
- AddBinding
Params - If executionContextId is empty, adds binding with the given name on the global objects of all inspected contexts, including those created later, bindings survive reloads. Binding function takes exactly one argument, this argument should be string, in case of any other input, function throws an exception. Each binding function call produces Runtime.bindingCalled notification.
- Await
Promise Params - Add handler to promise with given promise object id.
- Await
Promise Returns - Add handler to promise with given promise object id.
- Call
Argument - Represents function call argument. Either remote object id ‘objectId’, primitive ‘value’, unserializable primitive value or neither of (for undefined) them should be specified.
- Call
Frame - Stack entry for runtime errors and assertions.
- Call
Function OnParams - Calls function with given declaration on the given object. Object group of the result is inherited from the target object.
- Call
Function OnReturns - Calls function with given declaration on the given object. Object group of the result is inherited from the target object.
- Compile
Script Params - Compiles expression.
- Compile
Script Returns - Compiles expression.
- Custom
Preview - Deep
Serialized Value - Represents deep serialized value.
- Entry
Preview - Evaluate
Params - Evaluates expression on global object.
- Evaluate
Returns - Evaluates expression on global object.
- Exception
Details - Detailed information about exception (or error) that was thrown during script compilation or execution.
- Execution
Context Description - Description of an isolated world.
- GetException
Details Params - This method tries to lookup and populate exception details for a JavaScript Error object. Note that the stackTrace portion of the resulting exceptionDetails will only be populated if the Runtime domain was enabled at the time when the Error was thrown.
- GetException
Details Returns - This method tries to lookup and populate exception details for a JavaScript Error object. Note that the stackTrace portion of the resulting exceptionDetails will only be populated if the Runtime domain was enabled at the time when the Error was thrown.
- GetHeap
Usage Returns - Returns the JavaScript heap usage. It is the total usage of the corresponding isolate not scoped to a particular Runtime.
- GetIsolate
IdReturns - Returns the isolate id.
- GetProperties
Params - Returns properties of a given object. Object group of the result is inherited from the target object.
- GetProperties
Returns - Returns properties of a given object. Object group of the result is inherited from the target object.
- Global
Lexical Scope Names Params - Returns all let, const and class variables from global scope.
- Global
Lexical Scope Names Returns - Returns all let, const and class variables from global scope.
- Internal
Property Descriptor - Object internal property descriptor. This property isn’t normally visible in JavaScript code.
- Object
Preview - Object containing abbreviated remote object value.
- Private
Property Descriptor - Object private field descriptor.
- Property
Descriptor - Object property descriptor.
- Property
Preview - Query
Objects Params - Query
Objects Returns - Release
Object Group Params - Releases all remote objects that belong to a given group.
- Release
Object Params - Releases remote object with given id.
- Remote
Object - Mirror object referencing original JavaScript object.
- Remove
Binding Params - This method does not remove binding function from global object but unsubscribes current runtime agent from Runtime.bindingCalled notifications.
- RunScript
Params - Runs script with given id in a given context.
- RunScript
Returns - Runs script with given id in a given context.
- Serialization
Options - Represents options for serialization. Overrides ‘generatePreview’ and ‘returnByValue’.
- SetAsync
Call Stack Depth Params - Enables or disables async call stacks tracking.
- SetCustom
Object Formatter Enabled Params - SetMax
Call Stack Size ToCapture Params - Stack
Trace - Call frames for assertions or error messages.
- Stack
Trace Id - If ‘debuggerId’ is set stack trace comes from another debugger and can be resolved there. This allows to track cross-debugger calls. See ‘Runtime.StackTrace’ and ‘Debugger.paused’ for usages.
Type Aliases
- Execution
Context Id - Id of an execution context.
- Remote
Object Id - Unique object identifier.
- Script
Id - Unique script identifier.
- Time
Delta - Number of milliseconds.
- Timestamp
- Number of milliseconds since epoch.
- Unique
Debugger Id - Unique identifier of current debugger.
- Unserializable
Value - Primitive value which cannot be JSON-stringified. Includes values ‘-0’, ‘NaN’, ‘Infinity’, ‘-Infinity’, and bigint literals.