pub struct AwaitPromiseParams {
pub promiseObjectId: RemoteObjectId,
pub returnByValue: Option<bool>,
pub generatePreview: Option<bool>,
}Expand description
Add handler to promise with given promise object id.
Fields
promiseObjectId: RemoteObjectIdIdentifier of the promise.
returnByValue: Option<bool>Whether the result is expected to be a JSON object that should be sent by value.
generatePreview: Option<bool>Whether preview should be generated for the result.