pub struct CallFunctionOnParams<'a> { /* private fields */ }Expand description
Calls function with given declaration on the given object. Object group of the result is inherited from the target object.
Implementations
Sourceimpl<'a> CallFunctionOnParams<'a>
impl<'a> CallFunctionOnParams<'a>
Sourcepub fn builder(
function_declaration: impl Into<Cow<'a, str>>,
) -> CallFunctionOnParamsBuilder<'a>
pub fn builder( function_declaration: impl Into<Cow<'a, str>>, ) -> CallFunctionOnParamsBuilder<'a>
Creates a builder for this type with the required parameters:
function_declaration: Declaration of the function to call.
Sourcepub fn function_declaration(&self) -> &str
pub fn function_declaration(&self) -> &str
Declaration of the function to call.
Sourcepub fn object_id(&self) -> Option<&RemoteObjectId<'a>>
pub fn object_id(&self) -> Option<&RemoteObjectId<'a>>
Identifier of the object to call function on. Either objectId or executionContextId should be specified.
Sourcepub fn arguments(&self) -> Option<&[CallArgument<'a>]>
pub fn arguments(&self) -> Option<&[CallArgument<'a>]>
Call arguments. All call arguments must belong to the same JavaScript world as the target object.
Sourcepub fn silent(&self) -> Option<bool>
pub fn silent(&self) -> Option<bool>
In silent mode exceptions thrown during evaluation are not reported and do not pause execution. Overrides ‘setPauseOnException’ state.
Sourcepub fn return_by_value(&self) -> Option<bool>
pub fn return_by_value(&self) -> Option<bool>
Whether the result is expected to be a JSON object which should be sent by value. Can be overriden by ‘serializationOptions’.
Sourcepub fn generate_preview(&self) -> Option<bool>
pub fn generate_preview(&self) -> Option<bool>
Whether preview should be generated for the result.
Sourcepub fn user_gesture(&self) -> Option<bool>
pub fn user_gesture(&self) -> Option<bool>
Whether execution should be treated as initiated by user in the UI.
Sourcepub fn await_promise(&self) -> Option<bool>
pub fn await_promise(&self) -> Option<bool>
Whether execution should ‘await’ for resulting value and return once awaited promise is resolved.
Sourcepub fn execution_context_id(&self) -> Option<&ExecutionContextId>
pub fn execution_context_id(&self) -> Option<&ExecutionContextId>
Specifies execution context which global object will be used to call function on. Either executionContextId or objectId should be specified.
Sourcepub fn object_group(&self) -> Option<&str>
pub fn object_group(&self) -> Option<&str>
Symbolic group name that can be used to release multiple objects. If objectGroup is not specified and objectId is, objectGroup will be inherited from object.
Sourcepub fn throw_on_side_effect(&self) -> Option<bool>
pub fn throw_on_side_effect(&self) -> Option<bool>
Whether to throw an exception if side effect cannot be ruled out during evaluation.
Sourcepub fn unique_context_id(&self) -> Option<&str>
pub fn unique_context_id(&self) -> Option<&str>
An alternative way to specify the execution context to call function on. Compared to contextId that may be reused across processes, this is guaranteed to be system-unique, so it can be used to prevent accidental function call in context different than intended (e.g. as a result of navigation across process boundaries). This is mutually exclusive with ‘executionContextId’.
Sourcepub fn serialization_options(&self) -> Option<&SerializationOptions<'a>>
pub fn serialization_options(&self) -> Option<&SerializationOptions<'a>>
Specifies the result serialization. If provided, overrides ‘generatePreview’ and ‘returnByValue’.