pub struct CallFunctionOnParams {Show 13 fields
pub functionDeclaration: String,
pub objectId: Option<RemoteObjectId>,
pub arguments: Option<Vec<CallArgument>>,
pub silent: Option<bool>,
pub returnByValue: Option<bool>,
pub generatePreview: Option<bool>,
pub userGesture: Option<bool>,
pub awaitPromise: Option<bool>,
pub executionContextId: Option<ExecutionContextId>,
pub objectGroup: Option<String>,
pub throwOnSideEffect: Option<bool>,
pub uniqueContextId: Option<String>,
pub serializationOptions: Option<SerializationOptions>,
}Expand description
Calls function with given declaration on the given object. Object group of the result is inherited from the target object.
Fields
functionDeclaration: StringDeclaration of the function to call.
objectId: Option<RemoteObjectId>Identifier of the object to call function on. Either objectId or executionContextId should be specified.
arguments: Option<Vec<CallArgument>>Call arguments. All call arguments must belong to the same JavaScript world as the target object.
silent: Option<bool>In silent mode exceptions thrown during evaluation are not reported and do not pause execution. Overrides ‘setPauseOnException’ state.
returnByValue: Option<bool>Whether the result is expected to be a JSON object which should be sent by value. Can be overriden by ‘serializationOptions’.
generatePreview: Option<bool>Whether preview should be generated for the result.
userGesture: Option<bool>Whether execution should be treated as initiated by user in the UI.
awaitPromise: Option<bool>Whether execution should ‘await’ for resulting value and return once awaited promise is resolved.
executionContextId: Option<ExecutionContextId>Specifies execution context which global object will be used to call function on. Either executionContextId or objectId should be specified.
objectGroup: Option<String>Symbolic group name that can be used to release multiple objects. If objectGroup is not specified and objectId is, objectGroup will be inherited from object.
throwOnSideEffect: Option<bool>Whether to throw an exception if side effect cannot be ruled out during evaluation.
uniqueContextId: Option<String>An alternative way to specify the execution context to call function on. Compared to contextId that may be reused across processes, this is guaranteed to be system-unique, so it can be used to prevent accidental function call in context different than intended (e.g. as a result of navigation across process boundaries). This is mutually exclusive with ‘executionContextId’.
serializationOptions: Option<SerializationOptions>Specifies the result serialization. If provided, overrides ‘generatePreview’ and ‘returnByValue’.