CompileScriptParams

Struct CompileScriptParams 

pub struct CompileScriptParams {
    pub expression: String,
    pub sourceURL: String,
    pub persistScript: bool,
    pub executionContextId: Option<ExecutionContextId>,
}
Compiles expression.

Fields

expression: String

Expression to compile.

sourceURL: String

Source url to be set for the script.

persistScript: bool

Specifies whether the compiled script should be persisted.

executionContextId: Option<ExecutionContextId>

Specifies in which execution context to perform script run. If the parameter is omitted the evaluation will be performed in the context of the inspected page.

Implementations

Source

impl CompileScriptParams

pub const METHOD: &'static str = "Runtime.compileScript"