EvaluateParams

Struct EvaluateParams 

pub struct EvaluateParams<'a> { /* private fields */ }
Evaluates expression on global object.

Implementations

Source

impl<'a> EvaluateParams<'a>

pub fn builder(expression: impl Into<Cow<'a, str>>) -> EvaluateParamsBuilder<'a>

Creates a builder for this type with the required parameters:

  • expression: Expression to evaluate.
pub fn expression(&self) -> &str

Expression to evaluate.

pub fn object_group(&self) -> Option<&str>

Symbolic group name that can be used to release multiple objects.

pub fn include_command_line_api(&self) -> Option<bool>

Determines whether Command Line API should be available during the evaluation.

pub fn silent(&self) -> Option<bool>

In silent mode exceptions thrown during evaluation are not reported and do not pause execution. Overrides ‘setPauseOnException’ state.

pub fn context_id(&self) -> Option<&ExecutionContextId>

Specifies in which execution context to perform evaluation. If the parameter is omitted the evaluation will be performed in the context of the inspected page. This is mutually exclusive with ‘uniqueContextId’, which offers an alternative way to identify the execution context that is more reliable in a multi-process environment.

pub fn return_by_value(&self) -> Option<bool>

Whether the result is expected to be a JSON object that should be sent by value.

pub fn generate_preview(&self) -> Option<bool>

Whether preview should be generated for the result.

pub fn user_gesture(&self) -> Option<bool>

Whether execution should be treated as initiated by user in the UI.

pub fn await_promise(&self) -> Option<bool>

Whether execution should ‘await’ for resulting value and return once awaited promise is resolved.

pub fn throw_on_side_effect(&self) -> Option<bool>

Whether to throw an exception if side effect cannot be ruled out during evaluation. This implies ‘disableBreaks’ below.

pub fn timeout(&self) -> Option<&TimeDelta>

Terminate execution after timing out (number of milliseconds).

pub fn disable_breaks(&self) -> Option<bool>

Disable breakpoints during execution.

pub fn repl_mode(&self) -> Option<bool>

Setting this flag to true enables ‘let’ re-declaration and top-level ‘await’. Note that ‘let’ variables can only be re-declared if they originate from ‘replMode’ themselves.

pub fn allow_unsafe_eval_blocked_by_csp(&self) -> Option<bool>

The Content Security Policy (CSP) for the target might block ‘unsafe-eval’ which includes eval(), Function(), setTimeout() and setInterval() when called with non-callable arguments. This flag bypasses CSP for this evaluation and allows unsafe-eval. Defaults to true.

pub fn unique_context_id(&self) -> Option<&str>

An alternative way to specify the execution context to evaluate in. Compared to contextId that may be reused across processes, this is guaranteed to be system-unique, so it can be used to prevent accidental evaluation of the expression in context different than intended (e.g. as a result of navigation across process boundaries). This is mutually exclusive with ‘contextId’.

pub fn serialization_options(&self) -> Option<&SerializationOptions<'a>>

Specifies the result serialization. If provided, overrides ‘generatePreview’ and ‘returnByValue’.

Source

impl<'a> EvaluateParams<'a>

pub const METHOD: &'static str = "Runtime.evaluate"