pub struct EvaluateParams {Show 16 fields
pub expression: String,
pub objectGroup: Option<String>,
pub includeCommandLineAPI: Option<bool>,
pub silent: Option<bool>,
pub contextId: Option<ExecutionContextId>,
pub returnByValue: Option<bool>,
pub generatePreview: Option<bool>,
pub userGesture: Option<bool>,
pub awaitPromise: Option<bool>,
pub throwOnSideEffect: Option<bool>,
pub timeout: Option<TimeDelta>,
pub disableBreaks: Option<bool>,
pub replMode: Option<bool>,
pub allowUnsafeEvalBlockedByCSP: Option<bool>,
pub uniqueContextId: Option<String>,
pub serializationOptions: Option<SerializationOptions>,
}Expand description
Evaluates expression on global object.
Fields
expression: StringExpression to evaluate.
objectGroup: Option<String>Symbolic group name that can be used to release multiple objects.
includeCommandLineAPI: Option<bool>Determines whether Command Line API should be available during the evaluation.
silent: Option<bool>In silent mode exceptions thrown during evaluation are not reported and do not pause execution. Overrides ‘setPauseOnException’ state.
contextId: Option<ExecutionContextId>Specifies in which execution context to perform evaluation. If the parameter is omitted the evaluation will be performed in the context of the inspected page. This is mutually exclusive with ‘uniqueContextId’, which offers an alternative way to identify the execution context that is more reliable in a multi-process environment.
returnByValue: Option<bool>Whether the result is expected to be a JSON object that should be sent by value.
generatePreview: Option<bool>Whether preview should be generated for the result.
userGesture: Option<bool>Whether execution should be treated as initiated by user in the UI.
awaitPromise: Option<bool>Whether execution should ‘await’ for resulting value and return once awaited promise is resolved.
throwOnSideEffect: Option<bool>Whether to throw an exception if side effect cannot be ruled out during evaluation. This implies ‘disableBreaks’ below.
timeout: Option<TimeDelta>Terminate execution after timing out (number of milliseconds).
disableBreaks: Option<bool>Disable breakpoints during execution.
replMode: Option<bool>Setting this flag to true enables ‘let’ re-declaration and top-level ‘await’. Note that ‘let’ variables can only be re-declared if they originate from ‘replMode’ themselves.
allowUnsafeEvalBlockedByCSP: Option<bool>The Content Security Policy (CSP) for the target might block ‘unsafe-eval’ which includes eval(), Function(), setTimeout() and setInterval() when called with non-callable arguments. This flag bypasses CSP for this evaluation and allows unsafe-eval. Defaults to true.
uniqueContextId: Option<String>An alternative way to specify the execution context to evaluate in. Compared to contextId that may be reused across processes, this is guaranteed to be system-unique, so it can be used to prevent accidental evaluation of the expression in context different than intended (e.g. as a result of navigation across process boundaries). This is mutually exclusive with ‘contextId’.
serializationOptions: Option<SerializationOptions>Specifies the result serialization. If provided, overrides ‘generatePreview’ and ‘returnByValue’.
Implementations