pub struct ExceptionDetails<'a> { /* private fields */ }Expand description
Detailed information about exception (or error) that was thrown during script compilation or execution.
Implementations
Sourceimpl<'a> ExceptionDetails<'a>
impl<'a> ExceptionDetails<'a>
Sourcepub fn builder(
exception_id: u64,
text: impl Into<Cow<'a, str>>,
line_number: i64,
column_number: i64,
) -> ExceptionDetailsBuilder<'a>
pub fn builder( exception_id: u64, text: impl Into<Cow<'a, str>>, line_number: i64, column_number: i64, ) -> ExceptionDetailsBuilder<'a>
Creates a builder for this type with the required parameters:
exception_id: Exception id.text: Exception text, which should be used together with exception object when available.line_number: Line number of the exception location (0-based).column_number: Column number of the exception location (0-based).
Sourcepub fn exception_id(&self) -> u64
pub fn exception_id(&self) -> u64
Exception id.
Sourcepub fn text(&self) -> &str
pub fn text(&self) -> &str
Exception text, which should be used together with exception object when available.
Sourcepub fn line_number(&self) -> i64
pub fn line_number(&self) -> i64
Line number of the exception location (0-based).
Sourcepub fn column_number(&self) -> i64
pub fn column_number(&self) -> i64
Column number of the exception location (0-based).
Sourcepub fn url(&self) -> Option<&str>
pub fn url(&self) -> Option<&str>
URL of the exception location, to be used when the script was not reported.
Sourcepub fn stack_trace(&self) -> Option<&StackTrace<'a>>
pub fn stack_trace(&self) -> Option<&StackTrace<'a>>
JavaScript stack trace if available.
Sourcepub fn exception(&self) -> Option<&RemoteObject<'a>>
pub fn exception(&self) -> Option<&RemoteObject<'a>>
Exception object if available.
Sourcepub fn execution_context_id(&self) -> Option<&ExecutionContextId>
pub fn execution_context_id(&self) -> Option<&ExecutionContextId>
Identifier of the context where exception happened.