pub struct ExceptionDetails {
pub exceptionId: u64,
pub text: String,
pub lineNumber: i64,
pub columnNumber: i64,
pub scriptId: Option<ScriptId>,
pub url: Option<String>,
pub stackTrace: Option<StackTrace>,
pub exception: Option<RemoteObject>,
pub executionContextId: Option<ExecutionContextId>,
pub exceptionMetaData: Option<Map<String, Value>>,
}Expand description
Detailed information about exception (or error) that was thrown during script compilation or execution.
Fields
exceptionId: u64Exception id.
text: StringException text, which should be used together with exception object when available.
lineNumber: i64Line number of the exception location (0-based).
columnNumber: i64Column number of the exception location (0-based).
scriptId: Option<ScriptId>Script ID of the exception location.
url: Option<String>URL of the exception location, to be used when the script was not reported.
stackTrace: Option<StackTrace>JavaScript stack trace if available.
exception: Option<RemoteObject>Exception object if available.
executionContextId: Option<ExecutionContextId>Identifier of the context where exception happened.
exceptionMetaData: Option<Map<String, Value>>Dictionary with entries of meta data that the client associated with this exception, such as information about associated network requests, etc.