GetExceptionDetailsReturns

Struct GetExceptionDetailsReturns 

pub struct GetExceptionDetailsReturns<'a> { /* private fields */ }
This method tries to lookup and populate exception details for a JavaScript Error object. Note that the stackTrace portion of the resulting exceptionDetails will only be populated if the Runtime domain was enabled at the time when the Error was thrown.

Implementations

Source

impl<'a> GetExceptionDetailsReturns<'a>

pub fn builder() -> GetExceptionDetailsReturnsBuilder<'a>

Creates a builder for this type.

pub fn exception_details(&self) -> Option<&ExceptionDetails<'a>>