pub struct GetHeapUsageReturns {
pub usedSize: f64,
pub totalSize: f64,
pub embedderHeapUsedSize: f64,
pub backingStorageSize: f64,
}Expand description
Returns the JavaScript heap usage. It is the total usage of the corresponding isolate not scoped to a particular Runtime.
Fields
usedSize: f64Used JavaScript heap size in bytes.
totalSize: f64Allocated JavaScript heap size in bytes.
embedderHeapUsedSize: f64Used size in bytes in the embedder’s garbage-collected heap.
backingStorageSize: f64Size in bytes of backing storage for array buffers and external strings.