pub struct PropertyDescriptor {
pub name: String,
pub value: Option<RemoteObject>,
pub writable: Option<bool>,
pub get: Option<RemoteObject>,
pub set: Option<RemoteObject>,
pub configurable: bool,
pub enumerable: bool,
pub wasThrown: Option<bool>,
pub isOwn: Option<bool>,
pub symbol: Option<RemoteObject>,
}Expand description
Object property descriptor.
Fields
name: StringProperty name or symbol description.
value: Option<RemoteObject>The value associated with the property.
writable: Option<bool>True if the value associated with the property may be changed (data descriptors only).
get: Option<RemoteObject>A function which serves as a getter for the property, or ‘undefined’ if there is no getter (accessor descriptors only).
set: Option<RemoteObject>A function which serves as a setter for the property, or ‘undefined’ if there is no setter (accessor descriptors only).
configurable: boolTrue if the type of this property descriptor may be changed and if the property may be deleted from the corresponding object.
enumerable: boolTrue if this property shows up during enumeration of the properties on the corresponding object.
wasThrown: Option<bool>True if the result was thrown during the evaluation.
isOwn: Option<bool>True if the property is owned for the object.
symbol: Option<RemoteObject>Property symbol object, if the property is of the ‘symbol’ type.