PropertyDescriptorBuilder

Struct PropertyDescriptorBuilder 

pub struct PropertyDescriptorBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> PropertyDescriptorBuilder<'a>

pub fn value(self, value: RemoteObject<'a>) -> Self

The value associated with the property.

pub fn writable(self, writable: bool) -> Self

True if the value associated with the property may be changed (data descriptors only).

pub fn get(self, get: RemoteObject<'a>) -> Self

A function which serves as a getter for the property, or ‘undefined’ if there is no getter (accessor descriptors only).

pub fn set(self, set: RemoteObject<'a>) -> Self

A function which serves as a setter for the property, or ‘undefined’ if there is no setter (accessor descriptors only).

pub fn was_thrown(self, was_thrown: bool) -> Self

True if the result was thrown during the evaluation.

pub fn is_own(self, is_own: bool) -> Self

True if the property is owned for the object.

pub fn symbol(self, symbol: RemoteObject<'a>) -> Self

Property symbol object, if the property is of the ‘symbol’ type.

pub fn build(self) -> PropertyDescriptor<'a>