pub struct RemoteObject {
pub type_: String,
pub subtype: Option<String>,
pub className: Option<String>,
pub value: Option<Value>,
pub unserializableValue: Option<UnserializableValue>,
pub description: Option<String>,
pub deepSerializedValue: Option<DeepSerializedValue>,
pub objectId: Option<RemoteObjectId>,
pub preview: Option<ObjectPreview>,
pub customPreview: Option<CustomPreview>,
}Expand description
Mirror object referencing original JavaScript object.
Fields
type_: StringObject type.
subtype: Option<String>Object subtype hint. Specified for ‘object’ type values only. NOTE: If you change anything here, make sure to also update ‘subtype’ in ‘ObjectPreview’ and ‘PropertyPreview’ below.
className: Option<String>Object class (constructor) name. Specified for ‘object’ type values only.
value: Option<Value>Remote object value in case of primitive values or JSON values (if it was requested).
unserializableValue: Option<UnserializableValue>Primitive value which can not be JSON-stringified does not have ‘value’, but gets this property.
description: Option<String>String representation of the object.
deepSerializedValue: Option<DeepSerializedValue>Deep serialized value.
objectId: Option<RemoteObjectId>Unique object identifier (for non-primitive values).
preview: Option<ObjectPreview>Preview containing abbreviated property values. Specified for ‘object’ type values only.
customPreview: Option<CustomPreview>Trait Implementations
Sourceimpl Clone for RemoteObject
impl Clone for RemoteObject
Sourcefn clone(&self) -> RemoteObject
fn clone(&self) -> RemoteObject
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RemoteObject
impl Debug for RemoteObject
Sourceimpl Default for RemoteObject
impl Default for RemoteObject
Sourcefn default() -> RemoteObject
fn default() -> RemoteObject
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for RemoteObject
impl<'de> Deserialize<'de> for RemoteObject
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more