pub struct RunScriptParams {
pub scriptId: ScriptId,
pub executionContextId: Option<ExecutionContextId>,
pub objectGroup: Option<String>,
pub silent: Option<bool>,
pub includeCommandLineAPI: Option<bool>,
pub returnByValue: Option<bool>,
pub generatePreview: Option<bool>,
pub awaitPromise: Option<bool>,
}Expand description
Runs script with given id in a given context.
Fields
scriptId: ScriptIdId of the script to run.
executionContextId: Option<ExecutionContextId>Specifies in which execution context to perform script run. If the parameter is omitted the evaluation will be performed in the context of the inspected page.
objectGroup: Option<String>Symbolic group name that can be used to release multiple objects.
silent: Option<bool>In silent mode exceptions thrown during evaluation are not reported and do not pause execution. Overrides ‘setPauseOnException’ state.
includeCommandLineAPI: Option<bool>Determines whether Command Line API should be available during the evaluation.
returnByValue: Option<bool>Whether the result is expected to be a JSON object which should be sent by value.
generatePreview: Option<bool>Whether preview should be generated for the result.
awaitPromise: Option<bool>Whether execution should ‘await’ for resulting value and return once awaited promise is resolved.