RunScriptParamsBuilder

Struct RunScriptParamsBuilder 

pub struct RunScriptParamsBuilder<'a> { /* private fields */ }

Implementations

Source

impl<'a> RunScriptParamsBuilder<'a>

pub fn execution_context_id( self, execution_context_id: ExecutionContextId, ) -> Self

Specifies in which execution context to perform script run. If the parameter is omitted the evaluation will be performed in the context of the inspected page.

pub fn object_group(self, object_group: impl Into<Cow<'a, str>>) -> Self

Symbolic group name that can be used to release multiple objects.

pub fn silent(self, silent: bool) -> Self

In silent mode exceptions thrown during evaluation are not reported and do not pause execution. Overrides ‘setPauseOnException’ state.

pub fn include_command_line_api(self, include_command_line_api: bool) -> Self

Determines whether Command Line API should be available during the evaluation.

pub fn return_by_value(self, return_by_value: bool) -> Self

Whether the result is expected to be a JSON object which should be sent by value.

pub fn generate_preview(self, generate_preview: bool) -> Self

Whether preview should be generated for the result.

pub fn await_promise(self, await_promise: bool) -> Self

Whether execution should ‘await’ for resulting value and return once awaited promise is resolved.

pub fn build(self) -> RunScriptParams<'a>